%%
% Prolog program of pyrimidine example file (Relational/Pyrimidine).
%
% Example taken from relational.fit.cvut.cz/dataset/Pyrimidine


/** <examples>
?- induce_hplp([f1,f2,f3],P),test_hplp(P,[f4],LL,AUCROC,ROC,AUCPR,PR). % learn the structure and the parameters and test the result
?- induce_hplp([f1,f2,f3,f4],P). % learn the structure and the parameters
*/

:-use_module(library(phil)).
:- if(current_predicate(use_rendering/1)).
:- use_rendering(c3).
:- use_rendering(lpad).
:- endif.

:-phil.

:- set_hplp(verbosity,1).
% Structure learning settings
:- set_hplp(megaex_bottom,10). % max number of mega examples to considered in the generation of bottoms clauses
:- set_hplp(initial_clauses_per_megaex,1).
:- set_hplp(rate,1.0). % defines the probabilityu for going from the first layer to the second layer
:- set_hplp(max_layer,-1). % Define the max number of layer: -1 for the maximum depth possible 
:- set_hplp(min_probability,0.00001).  % threshold value of the probability under which a clauses is dropped out

% Parameter learning settings
:- set_hplp(algorithmType,dphil). % parameter learning algorithm dphil or emphil
% Maximun iteration and other stop conditions.
:- set_hplp(maxIter_phil,1000).  
:- set_hplp(epsilon_deep,0.0001). 
:- set_hplp(epsilon_deep_fraction,0.00001).

:- set_hplp(setSeed,yes). % Default value=no
:- set_hplp(c_seed,3035).
% regularization parameters 
:- set_hplp(regularized,no). % yes to enable regularization and no otherwise 
:- set_hplp(regularizationType,2). % 1 for L1, 2 for L2 and 3 for L3. L3 available only for emphil. If set to 0 no regularization is done
:- set_hplp(gamma,10). % regularization strength
:- set_hplp(gammaCount,0). 

% Adam parameter for dphil algorithm
:- set_hplp(adam_params,[0.1,0.9,0.999,1e-8]). % adam(Eta,Beta1,Beta2,Epsilon_adam_hat)
% Gradient descent strategy and the corresponding batch size
%:- set_hplp(batch_strategy,minibatch(50)).
%:- set_hplp(batch_strategy,stoch_minibatch(50)).
:- set_hplp(batch_strategy,batch).

fold(f1,[pyrimidine002,pyrimidine003,pyrimidine007,pyrimidine014,pyrimidine017,
         pyrimidine001,pyrimidine004,pyrimidine006,pyrimidine010,pyrimidine011]).
fold(f2,[pyrimidine021,pyrimidine023,pyrimidine024,pyrimidine025,pyrimidine026,
         pyrimidine012,pyrimidine013,pyrimidine015,pyrimidine016,pyrimidine022]).
fold(f3,[pyrimidine029,pyrimidine030,pyrimidine042,pyrimidine048,pyrimidine069,
         pyrimidine027,pyrimidine032,pyrimidine033,pyrimidine038,pyrimidine039]).
fold(f4,[pyrimidine070,pyrimidine071,pyrimidine072,pyrimidine073,pyrimidine074,
         pyrimidine041,pyrimidine044,pyrimidine045,pyrimidine054,pyrimidine056]).



output(active/0).

input(activity/1).
input(p1_polar/1).
input(p1_size/1).
input(p1_flex/1).
input(p1_h_donor/1).
input(p1_h_acceptor/1).
input(p1_pi_donor/1).
input(p1_pi_acceptor/1).
input(p1_polarizable/1).
input(p1_sigma/1).
input(p2_polar/1).
input(p2_size/1).
input(p2_flex/1).
input(p2_h_donor/1).
input(p2_h_acceptor/1).
input(p2_pi_donor/1).
input(p2_pi_acceptor/1).
input(p2_polarizable/1).
input(p2_sigma/1).
input(p3_polar/1).
input(p3_size/1).
input(p3_flex/1).
input(p3_h_donor/1).
input(p3_h_acceptor/1).
input(p3_pi_donor/1).
input(p3_pi_acceptor/1).
input(p3_polarizable/1).
input(p3_sigma/1).


modeh(*,active).

modeb(*,activity(-#actf)).
modeb(*,p1_polar(-#pol)).
modeb(*,p1_size(-#si)).
modeb(*,p1_flex(-#fl)).
modeb(*,p1_h_donor(-#h_d)).
modeb(*,p1_h_acceptor(-#h_a)).
modeb(*,p1_pi_donor(-#p_d)).
modeb(*,p1_pi_acceptor(-#p_a)).
modeb(*,p1_polarizable(-#polar)).
modeb(*,p1_sigma(-#s)).
modeb(*,p2_polar(-#pol)).
modeb(*,p2_size(-#si)).
modeb(*,p2_flex(-#fl)).
modeb(*,p2_h_donor(-#h_d)).
modeb(*,p2_h_acceptor(-#h_a)).
modeb(*,p2_pi_donor(-#p_d)).
modeb(*,p2_pi_acceptor(-#p_a)).
modeb(*,p2_polarizable(-#polar)).
modeb(*,p2_sigma(-#s)).
modeb(*,p3_polar(-#pol)).
modeb(*,p3_size(-#si)).
modeb(*,p3_flex(-#fl)).
modeb(*,p3_h_donor(-#h_d)).
modeb(*,p3_h_acceptor(-#h_a)).
modeb(*,p3_pi_donor(-#p_d)).
modeb(*,p3_pi_acceptor(-#p_a)).
modeb(*,p3_polarizable(-#polar)).
modeb(*,p3_sigma(-#s)).

determination(active/0,activity/1).
determination(active/0,p1_polar/1).
determination(active/0,p1_size/1).
determination(active/0,p1_flex/1).
determination(active/0,p1_h_donor/1).
determination(active/0,p1_h_acceptor/1).
determination(active/0,p1_pi_donor/1).
determination(active/0,p1_pi_acceptor/1).
determination(active/0,p1_polarizable/1).
determination(active/0,p1_sigma/1).
determination(active/0,p2_polar/1).
determination(active/0,p2_size/1).
determination(active/0,p2_flex/1).
determination(active/0,p2_h_donor/1).
determination(active/0,p2_h_acceptor/1).
determination(active/0,p2_pi_donor/1).
determination(active/0,p2_pi_acceptor/1).
determination(active/0,p2_polarizable/1).
determination(active/0,p2_sigma/1).
determination(active/0,p3_polar/1).
determination(active/0,p3_size/1).
determination(active/0,p3_flex/1).
determination(active/0,p3_h_donor/1).
determination(active/0,p3_h_acceptor/1).
determination(active/0,p3_pi_donor/1).
determination(active/0,p3_pi_acceptor/1).
determination(active/0,p3_polarizable/1).
determination(active/0,p3_sigma/1).


active(pyrimidine002).
active(pyrimidine003).
active(pyrimidine007).
active(pyrimidine014).
active(pyrimidine017).
active(pyrimidine021).
active(pyrimidine023).
active(pyrimidine024).
active(pyrimidine025).
active(pyrimidine026).
active(pyrimidine029).
active(pyrimidine030).
active(pyrimidine042).
active(pyrimidine048).
active(pyrimidine069).
active(pyrimidine070).
active(pyrimidine071).
active(pyrimidine072).
active(pyrimidine073).
active(pyrimidine074).


neg(active(pyrimidine001)).
neg(active(pyrimidine004)).
neg(active(pyrimidine006)).
neg(active(pyrimidine010)).
neg(active(pyrimidine011)).
neg(active(pyrimidine012)).
neg(active(pyrimidine013)).
neg(active(pyrimidine015)).
neg(active(pyrimidine016)).
neg(active(pyrimidine022)).
neg(active(pyrimidine027)).
neg(active(pyrimidine032)).
neg(active(pyrimidine033)).
neg(active(pyrimidine038)).
neg(active(pyrimidine039)).
neg(active(pyrimidine041)).
neg(active(pyrimidine044)).
neg(active(pyrimidine045)).
neg(active(pyrimidine054)).
neg(active(pyrimidine056)).


%active :- activity(_Act).
%neg(active) :- \+ active.

p1_polar(pyrimidine001,0.500000).
p1_size(pyrimidine001,0.260000).
p1_flex(pyrimidine001,0.100000).
p1_h_donor(pyrimidine001,0.900000).
p1_h_acceptor(pyrimidine001,0.900000).
p1_pi_donor(pyrimidine001,0.900000).
p1_pi_acceptor(pyrimidine001,0.100000).
p1_polarizable(pyrimidine001,0.367000).
p1_sigma(pyrimidine001,0.420000).
p2_polar(pyrimidine001,0.260000).
p2_size(pyrimidine001,0.100000).
p2_flex(pyrimidine001,0.100000).
p2_h_donor(pyrimidine001,0.100000).
p2_h_acceptor(pyrimidine001,0.100000).
p2_pi_donor(pyrimidine001,0.100000).
p2_pi_acceptor(pyrimidine001,0.100000).
p2_polarizable(pyrimidine001,0.100000).
p2_sigma(pyrimidine001,0.100000).
p3_polar(pyrimidine001,0.367000).
p3_size(pyrimidine001,0.100000).
p3_flex(pyrimidine001,0.100000).
p3_h_donor(pyrimidine001,0.100000).
p3_h_acceptor(pyrimidine001,0.100000).
p3_pi_donor(pyrimidine001,0.100000).
p3_pi_acceptor(pyrimidine001,0.100000).
p3_sigma(pyrimidine001,0.100000).
activity(pyrimidine001,0.571000).
p1_polar(pyrimidine002,0.500000).
p1_size(pyrimidine002,0.260000).
p1_flex(pyrimidine002,0.100000).
p1_h_donor(pyrimidine002,0.100000).
p1_h_acceptor(pyrimidine002,0.100000).
p1_pi_donor(pyrimidine002,0.500000).
p1_pi_acceptor(pyrimidine002,0.100000).
p1_polarizable(pyrimidine002,0.367000).
p1_sigma(pyrimidine002,0.580000).
p2_polar(pyrimidine002,0.420000).
p2_size(pyrimidine002,0.260000).
p2_flex(pyrimidine002,0.100000).
p2_h_donor(pyrimidine002,0.900000).
p2_h_acceptor(pyrimidine002,0.100000).
p2_pi_donor(pyrimidine002,0.900000).
p2_pi_acceptor(pyrimidine002,0.100000).
p2_polarizable(pyrimidine002,0.100000).
p2_sigma(pyrimidine002,0.260000).
p3_polar(pyrimidine002,0.900000).
p3_size(pyrimidine002,0.367000).
p3_flex(pyrimidine002,0.100000).
p3_h_donor(pyrimidine002,0.100000).
p3_h_acceptor(pyrimidine002,0.100000).
p3_pi_donor(pyrimidine002,0.500000).
p3_pi_acceptor(pyrimidine002,0.367000).
p3_sigma(pyrimidine002,0.900000).
activity(pyrimidine002,0.900000).
p1_polar(pyrimidine003,0.300000).
p1_size(pyrimidine003,0.420000).
p1_flex(pyrimidine003,0.100000).
p1_h_donor(pyrimidine003,0.100000).
p1_h_acceptor(pyrimidine003,0.500000).
p1_pi_donor(pyrimidine003,0.500000).
p1_pi_acceptor(pyrimidine003,0.100000).
p1_polarizable(pyrimidine003,0.367000).
p1_sigma(pyrimidine003,0.260000).
p2_polar(pyrimidine003,0.260000).
p2_size(pyrimidine003,0.100000).
p2_flex(pyrimidine003,0.100000).
p2_h_donor(pyrimidine003,0.100000).
p2_h_acceptor(pyrimidine003,0.100000).
p2_pi_donor(pyrimidine003,0.100000).
p2_pi_acceptor(pyrimidine003,0.100000).
p2_polarizable(pyrimidine003,0.100000).
p2_sigma(pyrimidine003,0.100000).
p3_polar(pyrimidine003,0.633000).
p3_size(pyrimidine003,0.633000).
p3_flex(pyrimidine003,0.100000).
p3_h_donor(pyrimidine003,0.100000).
p3_h_acceptor(pyrimidine003,0.500000).
p3_pi_donor(pyrimidine003,0.500000).
p3_pi_acceptor(pyrimidine003,0.367000).
p3_sigma(pyrimidine003,0.367000).
activity(pyrimidine003,0.833000).
p1_polar(pyrimidine004,0.100000).
p1_size(pyrimidine004,0.740000).
p1_flex(pyrimidine004,0.700000).
p1_h_donor(pyrimidine004,0.100000).
p1_h_acceptor(pyrimidine004,0.500000).
p1_pi_donor(pyrimidine004,0.100000).
p1_pi_acceptor(pyrimidine004,0.100000).
p1_polarizable(pyrimidine004,0.367000).
p1_sigma(pyrimidine004,0.100000).
p2_polar(pyrimidine004,0.260000).
p2_size(pyrimidine004,0.100000).
p2_flex(pyrimidine004,0.100000).
p2_h_donor(pyrimidine004,0.100000).
p2_h_acceptor(pyrimidine004,0.100000).
p2_pi_donor(pyrimidine004,0.100000).
p2_pi_acceptor(pyrimidine004,0.100000).
p2_polarizable(pyrimidine004,0.100000).
p2_sigma(pyrimidine004,0.100000).
p3_polar(pyrimidine004,0.367000).
p3_size(pyrimidine004,0.100000).
p3_flex(pyrimidine004,0.100000).
p3_h_donor(pyrimidine004,0.100000).
p3_h_acceptor(pyrimidine004,0.100000).
p3_pi_donor(pyrimidine004,0.100000).
p3_pi_acceptor(pyrimidine004,0.100000).
p3_sigma(pyrimidine004,0.100000).
activity(pyrimidine004,0.582000).
p1_polar(pyrimidine005,0.100000).
p1_size(pyrimidine005,0.420000).
p1_flex(pyrimidine005,0.400000).
p1_h_donor(pyrimidine005,0.100000).
p1_h_acceptor(pyrimidine005,0.500000).
p1_pi_donor(pyrimidine005,0.100000).
p1_pi_acceptor(pyrimidine005,0.100000).
p1_polarizable(pyrimidine005,0.367000).
p1_sigma(pyrimidine005,0.100000).
p2_polar(pyrimidine005,0.260000).
p2_size(pyrimidine005,0.100000).
p2_flex(pyrimidine005,0.100000).
p2_h_donor(pyrimidine005,0.100000).
p2_h_acceptor(pyrimidine005,0.100000).
p2_pi_donor(pyrimidine005,0.100000).
p2_pi_acceptor(pyrimidine005,0.100000).
p2_polarizable(pyrimidine005,0.100000).
p2_sigma(pyrimidine005,0.100000).
p3_polar(pyrimidine005,0.367000).
p3_size(pyrimidine005,0.100000).
p3_flex(pyrimidine005,0.100000).
p3_h_donor(pyrimidine005,0.100000).
p3_h_acceptor(pyrimidine005,0.100000).
p3_pi_donor(pyrimidine005,0.100000).
p3_pi_acceptor(pyrimidine005,0.100000).
p3_sigma(pyrimidine005,0.100000).
activity(pyrimidine005,0.587000).
p1_polar(pyrimidine006,0.300000).
p1_size(pyrimidine006,0.420000).
p1_flex(pyrimidine006,0.300000).
p1_h_donor(pyrimidine006,0.900000).
p1_h_acceptor(pyrimidine006,0.900000).
p1_pi_donor(pyrimidine006,0.100000).
p1_pi_acceptor(pyrimidine006,0.100000).
p1_polarizable(pyrimidine006,0.367000).
p1_sigma(pyrimidine006,0.100000).
p2_polar(pyrimidine006,0.260000).
p2_size(pyrimidine006,0.100000).
p2_flex(pyrimidine006,0.100000).
p2_h_donor(pyrimidine006,0.100000).
p2_h_acceptor(pyrimidine006,0.100000).
p2_pi_donor(pyrimidine006,0.100000).
p2_pi_acceptor(pyrimidine006,0.100000).
p2_polarizable(pyrimidine006,0.100000).
p2_sigma(pyrimidine006,0.100000).
p3_polar(pyrimidine006,0.633000).
p3_size(pyrimidine006,0.633000).
p3_flex(pyrimidine006,0.633000).
p3_h_donor(pyrimidine006,0.900000).
p3_h_acceptor(pyrimidine006,0.900000).
p3_pi_donor(pyrimidine006,0.100000).
p3_pi_acceptor(pyrimidine006,0.367000).
p3_sigma(pyrimidine006,0.100000).
activity(pyrimidine006,0.549000).
p1_polar(pyrimidine007,0.300000).
p1_size(pyrimidine007,0.420000).
p1_flex(pyrimidine007,0.100000).
p1_h_donor(pyrimidine007,0.100000).
p1_h_acceptor(pyrimidine007,0.500000).
p1_pi_donor(pyrimidine007,0.500000).
p1_pi_acceptor(pyrimidine007,0.100000).
p1_polarizable(pyrimidine007,0.367000).
p1_sigma(pyrimidine007,0.260000).
p2_polar(pyrimidine007,0.420000).
p2_size(pyrimidine007,0.420000).
p2_flex(pyrimidine007,0.100000).
p2_h_donor(pyrimidine007,0.100000).
p2_h_acceptor(pyrimidine007,0.500000).
p2_pi_donor(pyrimidine007,0.500000).
p2_pi_acceptor(pyrimidine007,0.100000).
p2_polarizable(pyrimidine007,0.500000).
p2_sigma(pyrimidine007,0.260000).
p3_polar(pyrimidine007,0.367000).
p3_size(pyrimidine007,0.100000).
p3_flex(pyrimidine007,0.100000).
p3_h_donor(pyrimidine007,0.100000).
p3_h_acceptor(pyrimidine007,0.100000).
p3_pi_donor(pyrimidine007,0.100000).
p3_pi_acceptor(pyrimidine007,0.100000).
p3_sigma(pyrimidine007,0.100000).
activity(pyrimidine007,0.742000).
p1_polar(pyrimidine008,0.300000).
p1_size(pyrimidine008,0.420000).
p1_flex(pyrimidine008,0.100000).
p1_h_donor(pyrimidine008,0.100000).
p1_h_acceptor(pyrimidine008,0.500000).
p1_pi_donor(pyrimidine008,0.500000).
p1_pi_acceptor(pyrimidine008,0.100000).
p1_polarizable(pyrimidine008,0.367000).
p1_sigma(pyrimidine008,0.260000).
p2_polar(pyrimidine008,0.260000).
p2_size(pyrimidine008,0.100000).
p2_flex(pyrimidine008,0.100000).
p2_h_donor(pyrimidine008,0.100000).
p2_h_acceptor(pyrimidine008,0.100000).
p2_pi_donor(pyrimidine008,0.100000).
p2_pi_acceptor(pyrimidine008,0.100000).
p2_polarizable(pyrimidine008,0.100000).
p2_sigma(pyrimidine008,0.100000).
p3_polar(pyrimidine008,0.367000).
p3_size(pyrimidine008,0.100000).
p3_flex(pyrimidine008,0.100000).
p3_h_donor(pyrimidine008,0.100000).
p3_h_acceptor(pyrimidine008,0.100000).
p3_pi_donor(pyrimidine008,0.100000).
p3_pi_acceptor(pyrimidine008,0.100000).
p3_sigma(pyrimidine008,0.100000).
activity(pyrimidine008,0.634000).
p1_polar(pyrimidine009,0.900000).
p1_size(pyrimidine009,0.420000).
p1_flex(pyrimidine009,0.100000).
p1_h_donor(pyrimidine009,0.100000).
p1_h_acceptor(pyrimidine009,0.100000).
p1_pi_donor(pyrimidine009,0.100000).
p1_pi_acceptor(pyrimidine009,0.900000).
p1_polarizable(pyrimidine009,0.100000).
p1_sigma(pyrimidine009,0.580000).
p2_polar(pyrimidine009,0.420000).
p2_size(pyrimidine009,0.420000).
p2_flex(pyrimidine009,0.100000).
p2_h_donor(pyrimidine009,0.500000).
p2_h_acceptor(pyrimidine009,0.500000).
p2_pi_donor(pyrimidine009,0.500000).
p2_pi_acceptor(pyrimidine009,0.100000).
p2_polarizable(pyrimidine009,0.500000).
p2_sigma(pyrimidine009,0.260000).
p3_polar(pyrimidine009,0.367000).
p3_size(pyrimidine009,0.100000).
p3_flex(pyrimidine009,0.100000).
p3_h_donor(pyrimidine009,0.100000).
p3_h_acceptor(pyrimidine009,0.100000).
p3_pi_donor(pyrimidine009,0.100000).
p3_pi_acceptor(pyrimidine009,0.100000).
p3_sigma(pyrimidine009,0.100000).
activity(pyrimidine009,0.639000).
p1_polar(pyrimidine010,0.500000).
p1_size(pyrimidine010,0.260000).
p1_flex(pyrimidine010,0.100000).
p1_h_donor(pyrimidine010,0.900000).
p1_h_acceptor(pyrimidine010,0.900000).
p1_pi_donor(pyrimidine010,0.900000).
p1_pi_acceptor(pyrimidine010,0.100000).
p1_polarizable(pyrimidine010,0.367000).
p1_sigma(pyrimidine010,0.420000).
p2_polar(pyrimidine010,0.260000).
p2_size(pyrimidine010,0.100000).
p2_flex(pyrimidine010,0.100000).
p2_h_donor(pyrimidine010,0.100000).
p2_h_acceptor(pyrimidine010,0.100000).
p2_pi_donor(pyrimidine010,0.100000).
p2_pi_acceptor(pyrimidine010,0.100000).
p2_polarizable(pyrimidine010,0.100000).
p2_sigma(pyrimidine010,0.100000).
p3_polar(pyrimidine010,0.900000).
p3_size(pyrimidine010,0.367000).
p3_flex(pyrimidine010,0.100000).
p3_h_donor(pyrimidine010,0.900000).
p3_h_acceptor(pyrimidine010,0.900000).
p3_pi_donor(pyrimidine010,0.900000).
p3_pi_acceptor(pyrimidine010,0.367000).
p3_sigma(pyrimidine010,0.633000).
activity(pyrimidine010,0.100000).
p1_polar(pyrimidine011,0.100000).
p1_size(pyrimidine011,0.100000).
p1_flex(pyrimidine011,0.100000).
p1_h_donor(pyrimidine011,0.100000).
p1_h_acceptor(pyrimidine011,0.100000).
p1_pi_donor(pyrimidine011,0.100000).
p1_pi_acceptor(pyrimidine011,0.100000).
p1_polarizable(pyrimidine011,0.100000).
p1_sigma(pyrimidine011,0.100000).
p2_polar(pyrimidine011,0.420000).
p2_size(pyrimidine011,0.260000).
p2_flex(pyrimidine011,0.100000).
p2_h_donor(pyrimidine011,0.900000).
p2_h_acceptor(pyrimidine011,0.100000).
p2_pi_donor(pyrimidine011,0.900000).
p2_pi_acceptor(pyrimidine011,0.100000).
p2_polarizable(pyrimidine011,0.100000).
p2_sigma(pyrimidine011,0.260000).
p3_polar(pyrimidine011,0.367000).
p3_size(pyrimidine011,0.100000).
p3_flex(pyrimidine011,0.100000).
p3_h_donor(pyrimidine011,0.100000).
p3_h_acceptor(pyrimidine011,0.100000).
p3_pi_donor(pyrimidine011,0.100000).
p3_pi_acceptor(pyrimidine011,0.100000).
p3_sigma(pyrimidine011,0.100000).
activity(pyrimidine011,0.547000).
p1_polar(pyrimidine012,0.100000).
p1_size(pyrimidine012,0.100000).
p1_flex(pyrimidine012,0.100000).
p1_h_donor(pyrimidine012,0.100000).
p1_h_acceptor(pyrimidine012,0.100000).
p1_pi_donor(pyrimidine012,0.100000).
p1_pi_acceptor(pyrimidine012,0.100000).
p1_polarizable(pyrimidine012,0.100000).
p1_sigma(pyrimidine012,0.100000).
p2_polar(pyrimidine012,0.580000).
p2_size(pyrimidine012,0.260000).
p2_flex(pyrimidine012,0.100000).
p2_h_donor(pyrimidine012,0.100000).
p2_h_acceptor(pyrimidine012,0.100000).
p2_pi_donor(pyrimidine012,0.500000).
p2_pi_acceptor(pyrimidine012,0.100000).
p2_polarizable(pyrimidine012,0.500000).
p2_sigma(pyrimidine012,0.580000).
p3_polar(pyrimidine012,0.367000).
p3_size(pyrimidine012,0.100000).
p3_flex(pyrimidine012,0.100000).
p3_h_donor(pyrimidine012,0.100000).
p3_h_acceptor(pyrimidine012,0.100000).
p3_pi_donor(pyrimidine012,0.100000).
p3_pi_acceptor(pyrimidine012,0.100000).
p3_sigma(pyrimidine012,0.100000).
activity(pyrimidine012,0.568000).
p1_polar(pyrimidine013,0.100000).
p1_size(pyrimidine013,0.100000).
p1_flex(pyrimidine013,0.100000).
p1_h_donor(pyrimidine013,0.100000).
p1_h_acceptor(pyrimidine013,0.100000).
p1_pi_donor(pyrimidine013,0.100000).
p1_pi_acceptor(pyrimidine013,0.100000).
p1_polarizable(pyrimidine013,0.100000).
p1_sigma(pyrimidine013,0.100000).
p2_polar(pyrimidine013,0.420000).
p2_size(pyrimidine013,0.900000).
p2_flex(pyrimidine013,0.700000).
p2_h_donor(pyrimidine013,0.100000).
p2_h_acceptor(pyrimidine013,0.500000).
p2_pi_donor(pyrimidine013,0.500000).
p2_pi_acceptor(pyrimidine013,0.100000).
p2_polarizable(pyrimidine013,0.500000).
p2_sigma(pyrimidine013,0.260000).
p3_polar(pyrimidine013,0.367000).
p3_size(pyrimidine013,0.100000).
p3_flex(pyrimidine013,0.100000).
p3_h_donor(pyrimidine013,0.100000).
p3_h_acceptor(pyrimidine013,0.100000).
p3_pi_donor(pyrimidine013,0.100000).
p3_pi_acceptor(pyrimidine013,0.100000).
p3_sigma(pyrimidine013,0.100000).
activity(pyrimidine013,0.516000).
p1_polar(pyrimidine014,0.500000).
p1_size(pyrimidine014,0.260000).
p1_flex(pyrimidine014,0.100000).
p1_h_donor(pyrimidine014,0.100000).
p1_h_acceptor(pyrimidine014,0.100000).
p1_pi_donor(pyrimidine014,0.500000).
p1_pi_acceptor(pyrimidine014,0.100000).
p1_polarizable(pyrimidine014,0.367000).
p1_sigma(pyrimidine014,0.580000).
p2_polar(pyrimidine014,0.420000).
p2_size(pyrimidine014,0.260000).
p2_flex(pyrimidine014,0.100000).
p2_h_donor(pyrimidine014,0.900000).
p2_h_acceptor(pyrimidine014,0.100000).
p2_pi_donor(pyrimidine014,0.900000).
p2_pi_acceptor(pyrimidine014,0.100000).
p2_polarizable(pyrimidine014,0.100000).
p2_sigma(pyrimidine014,0.260000).
p3_polar(pyrimidine014,0.367000).
p3_size(pyrimidine014,0.367000).
p3_flex(pyrimidine014,0.100000).
p3_h_donor(pyrimidine014,0.100000).
p3_h_acceptor(pyrimidine014,0.100000).
p3_pi_donor(pyrimidine014,0.100000).
p3_pi_acceptor(pyrimidine014,0.367000).
p3_sigma(pyrimidine014,0.100000).
activity(pyrimidine014,0.900000).
p1_polar(pyrimidine015,0.900000).
p1_size(pyrimidine015,0.260000).
p1_flex(pyrimidine015,0.100000).
p1_h_donor(pyrimidine015,0.100000).
p1_h_acceptor(pyrimidine015,0.500000).
p1_pi_donor(pyrimidine015,0.100000).
p1_pi_acceptor(pyrimidine015,0.100000).
p1_polarizable(pyrimidine015,0.100000).
p1_sigma(pyrimidine015,0.900000).
p2_polar(pyrimidine015,0.260000).
p2_size(pyrimidine015,0.100000).
p2_flex(pyrimidine015,0.100000).
p2_h_donor(pyrimidine015,0.100000).
p2_h_acceptor(pyrimidine015,0.100000).
p2_pi_donor(pyrimidine015,0.100000).
p2_pi_acceptor(pyrimidine015,0.100000).
p2_polarizable(pyrimidine015,0.100000).
p2_sigma(pyrimidine015,0.100000).
p3_polar(pyrimidine015,0.367000).
p3_size(pyrimidine015,0.100000).
p3_flex(pyrimidine015,0.100000).
p3_h_donor(pyrimidine015,0.100000).
p3_h_acceptor(pyrimidine015,0.100000).
p3_pi_donor(pyrimidine015,0.100000).
p3_pi_acceptor(pyrimidine015,0.100000).
p3_sigma(pyrimidine015,0.100000).
activity(pyrimidine015,0.538000).
p1_polar(pyrimidine016,0.100000).
p1_size(pyrimidine016,0.100000).
p1_flex(pyrimidine016,0.100000).
p1_h_donor(pyrimidine016,0.100000).
p1_h_acceptor(pyrimidine016,0.100000).
p1_pi_donor(pyrimidine016,0.100000).
p1_pi_acceptor(pyrimidine016,0.100000).
p1_polarizable(pyrimidine016,0.100000).
p1_sigma(pyrimidine016,0.100000).
p2_polar(pyrimidine016,0.260000).
p2_size(pyrimidine016,0.100000).
p2_flex(pyrimidine016,0.100000).
p2_h_donor(pyrimidine016,0.100000).
p2_h_acceptor(pyrimidine016,0.100000).
p2_pi_donor(pyrimidine016,0.100000).
p2_pi_acceptor(pyrimidine016,0.100000).
p2_polarizable(pyrimidine016,0.100000).
p2_sigma(pyrimidine016,0.100000).
p3_polar(pyrimidine016,0.367000).
p3_size(pyrimidine016,0.100000).
p3_flex(pyrimidine016,0.100000).
p3_h_donor(pyrimidine016,0.100000).
p3_h_acceptor(pyrimidine016,0.100000).
p3_pi_donor(pyrimidine016,0.100000).
p3_pi_acceptor(pyrimidine016,0.100000).
p3_sigma(pyrimidine016,0.100000).
activity(pyrimidine016,0.531000).
p1_polar(pyrimidine017,0.300000).
p1_size(pyrimidine017,0.420000).
p1_flex(pyrimidine017,0.100000).
p1_h_donor(pyrimidine017,0.100000).
p1_h_acceptor(pyrimidine017,0.500000).
p1_pi_donor(pyrimidine017,0.500000).
p1_pi_acceptor(pyrimidine017,0.100000).
p1_polarizable(pyrimidine017,0.367000).
p1_sigma(pyrimidine017,0.260000).
p2_polar(pyrimidine017,0.420000).
p2_size(pyrimidine017,0.900000).
p2_flex(pyrimidine017,0.700000).
p2_h_donor(pyrimidine017,0.100000).
p2_h_acceptor(pyrimidine017,0.500000).
p2_pi_donor(pyrimidine017,0.500000).
p2_pi_acceptor(pyrimidine017,0.100000).
p2_polarizable(pyrimidine017,0.500000).
p2_sigma(pyrimidine017,0.260000).
p3_polar(pyrimidine017,0.633000).
p3_size(pyrimidine017,0.633000).
p3_flex(pyrimidine017,0.100000).
p3_h_donor(pyrimidine017,0.100000).
p3_h_acceptor(pyrimidine017,0.500000).
p3_pi_donor(pyrimidine017,0.500000).
p3_pi_acceptor(pyrimidine017,0.367000).
p3_sigma(pyrimidine017,0.367000).
activity(pyrimidine017,0.763000).
p1_polar(pyrimidine018,0.300000).
p1_size(pyrimidine018,0.580000).
p1_flex(pyrimidine018,0.500000).
p1_h_donor(pyrimidine018,0.100000).
p1_h_acceptor(pyrimidine018,0.500000).
p1_pi_donor(pyrimidine018,0.500000).
p1_pi_acceptor(pyrimidine018,0.100000).
p1_polarizable(pyrimidine018,0.367000).
p1_sigma(pyrimidine018,0.260000).
p2_polar(pyrimidine018,0.260000).
p2_size(pyrimidine018,0.100000).
p2_flex(pyrimidine018,0.100000).
p2_h_donor(pyrimidine018,0.100000).
p2_h_acceptor(pyrimidine018,0.100000).
p2_pi_donor(pyrimidine018,0.100000).
p2_pi_acceptor(pyrimidine018,0.100000).
p2_polarizable(pyrimidine018,0.100000).
p2_sigma(pyrimidine018,0.100000).
p3_polar(pyrimidine018,0.367000).
p3_size(pyrimidine018,0.100000).
p3_flex(pyrimidine018,0.100000).
p3_h_donor(pyrimidine018,0.100000).
p3_h_acceptor(pyrimidine018,0.100000).
p3_pi_donor(pyrimidine018,0.100000).
p3_pi_acceptor(pyrimidine018,0.100000).
p3_sigma(pyrimidine018,0.100000).
activity(pyrimidine018,0.619000).
p1_polar(pyrimidine019,0.100000).
p1_size(pyrimidine019,0.100000).
p1_flex(pyrimidine019,0.100000).
p1_h_donor(pyrimidine019,0.100000).
p1_h_acceptor(pyrimidine019,0.100000).
p1_pi_donor(pyrimidine019,0.100000).
p1_pi_acceptor(pyrimidine019,0.100000).
p1_polarizable(pyrimidine019,0.100000).
p1_sigma(pyrimidine019,0.100000).
p2_polar(pyrimidine019,0.260000).
p2_size(pyrimidine019,0.420000).
p2_flex(pyrimidine019,0.100000).
p2_h_donor(pyrimidine019,0.100000).
p2_h_acceptor(pyrimidine019,0.500000).
p2_pi_donor(pyrimidine019,0.900000).
p2_pi_acceptor(pyrimidine019,0.100000).
p2_polarizable(pyrimidine019,0.500000).
p2_sigma(pyrimidine019,0.260000).
p3_polar(pyrimidine019,0.367000).
p3_size(pyrimidine019,0.100000).
p3_flex(pyrimidine019,0.100000).
p3_h_donor(pyrimidine019,0.100000).
p3_h_acceptor(pyrimidine019,0.100000).
p3_pi_donor(pyrimidine019,0.100000).
p3_pi_acceptor(pyrimidine019,0.100000).
p3_sigma(pyrimidine019,0.100000).
activity(pyrimidine019,0.613000).
p1_polar(pyrimidine020,0.100000).
p1_size(pyrimidine020,0.100000).
p1_flex(pyrimidine020,0.100000).
p1_h_donor(pyrimidine020,0.100000).
p1_h_acceptor(pyrimidine020,0.100000).
p1_pi_donor(pyrimidine020,0.100000).
p1_pi_acceptor(pyrimidine020,0.100000).
p1_polarizable(pyrimidine020,0.100000).
p1_sigma(pyrimidine020,0.100000).
p2_polar(pyrimidine020,0.420000).
p2_size(pyrimidine020,0.420000).
p2_flex(pyrimidine020,0.100000).
p2_h_donor(pyrimidine020,0.100000).
p2_h_acceptor(pyrimidine020,0.500000).
p2_pi_donor(pyrimidine020,0.500000).
p2_pi_acceptor(pyrimidine020,0.100000).
p2_polarizable(pyrimidine020,0.500000).
p2_sigma(pyrimidine020,0.260000).
p3_polar(pyrimidine020,0.367000).
p3_size(pyrimidine020,0.100000).
p3_flex(pyrimidine020,0.100000).
p3_h_donor(pyrimidine020,0.100000).
p3_h_acceptor(pyrimidine020,0.100000).
p3_pi_donor(pyrimidine020,0.100000).
p3_pi_acceptor(pyrimidine020,0.100000).
p3_sigma(pyrimidine020,0.100000).
activity(pyrimidine020,0.619000).
p1_polar(pyrimidine021,0.300000).
p1_size(pyrimidine021,0.420000).
p1_flex(pyrimidine021,0.100000).
p1_h_donor(pyrimidine021,0.100000).
p1_h_acceptor(pyrimidine021,0.500000).
p1_pi_donor(pyrimidine021,0.500000).
p1_pi_acceptor(pyrimidine021,0.100000).
p1_polarizable(pyrimidine021,0.367000).
p1_sigma(pyrimidine021,0.260000).
p2_polar(pyrimidine021,0.260000).
p2_size(pyrimidine021,0.260000).
p2_flex(pyrimidine021,0.100000).
p2_h_donor(pyrimidine021,0.100000).
p2_h_acceptor(pyrimidine021,0.100000).
p2_pi_donor(pyrimidine021,0.100000).
p2_pi_acceptor(pyrimidine021,0.100000).
p2_polarizable(pyrimidine021,0.500000).
p2_sigma(pyrimidine021,0.100000).
p3_polar(pyrimidine021,0.633000).
p3_size(pyrimidine021,0.633000).
p3_flex(pyrimidine021,0.100000).
p3_h_donor(pyrimidine021,0.100000).
p3_h_acceptor(pyrimidine021,0.500000).
p3_pi_donor(pyrimidine021,0.500000).
p3_pi_acceptor(pyrimidine021,0.367000).
p3_sigma(pyrimidine021,0.367000).
activity(pyrimidine021,0.859000).
p1_polar(pyrimidine022,0.300000).
p1_size(pyrimidine022,0.900000).
p1_flex(pyrimidine022,0.900000).
p1_h_donor(pyrimidine022,0.100000).
p1_h_acceptor(pyrimidine022,0.500000).
p1_pi_donor(pyrimidine022,0.500000).
p1_pi_acceptor(pyrimidine022,0.100000).
p1_polarizable(pyrimidine022,0.367000).
p1_sigma(pyrimidine022,0.260000).
p2_polar(pyrimidine022,0.260000).
p2_size(pyrimidine022,0.100000).
p2_flex(pyrimidine022,0.100000).
p2_h_donor(pyrimidine022,0.100000).
p2_h_acceptor(pyrimidine022,0.100000).
p2_pi_donor(pyrimidine022,0.100000).
p2_pi_acceptor(pyrimidine022,0.100000).
p2_polarizable(pyrimidine022,0.100000).
p2_sigma(pyrimidine022,0.100000).
p3_polar(pyrimidine022,0.367000).
p3_size(pyrimidine022,0.100000).
p3_flex(pyrimidine022,0.100000).
p3_h_donor(pyrimidine022,0.100000).
p3_h_acceptor(pyrimidine022,0.100000).
p3_pi_donor(pyrimidine022,0.100000).
p3_pi_acceptor(pyrimidine022,0.100000).
p3_sigma(pyrimidine022,0.100000).
activity(pyrimidine022,0.540000).
p1_polar(pyrimidine023,0.300000).
p1_size(pyrimidine023,0.260000).
p1_flex(pyrimidine023,0.100000).
p1_h_donor(pyrimidine023,0.100000).
p1_h_acceptor(pyrimidine023,0.100000).
p1_pi_donor(pyrimidine023,0.500000).
p1_pi_acceptor(pyrimidine023,0.100000).
p1_polarizable(pyrimidine023,0.900000).
p1_sigma(pyrimidine023,0.260000).
p2_polar(pyrimidine023,0.420000).
p2_size(pyrimidine023,0.420000).
p2_flex(pyrimidine023,0.100000).
p2_h_donor(pyrimidine023,0.100000).
p2_h_acceptor(pyrimidine023,0.500000).
p2_pi_donor(pyrimidine023,0.500000).
p2_pi_acceptor(pyrimidine023,0.100000).
p2_polarizable(pyrimidine023,0.500000).
p2_sigma(pyrimidine023,0.260000).
p3_polar(pyrimidine023,0.633000).
p3_size(pyrimidine023,0.367000).
p3_flex(pyrimidine023,0.100000).
p3_h_donor(pyrimidine023,0.100000).
p3_h_acceptor(pyrimidine023,0.100000).
p3_pi_donor(pyrimidine023,0.500000).
p3_pi_acceptor(pyrimidine023,0.900000).
p3_sigma(pyrimidine023,0.367000).
activity(pyrimidine023,0.893000).
p1_polar(pyrimidine024,0.300000).
p1_size(pyrimidine024,0.420000).
p1_flex(pyrimidine024,0.100000).
p1_h_donor(pyrimidine024,0.100000).
p1_h_acceptor(pyrimidine024,0.500000).
p1_pi_donor(pyrimidine024,0.500000).
p1_pi_acceptor(pyrimidine024,0.100000).
p1_polarizable(pyrimidine024,0.367000).
p1_sigma(pyrimidine024,0.260000).
p2_polar(pyrimidine024,0.420000).
p2_size(pyrimidine024,0.740000).
p2_flex(pyrimidine024,0.300000).
p2_h_donor(pyrimidine024,0.100000).
p2_h_acceptor(pyrimidine024,0.500000).
p2_pi_donor(pyrimidine024,0.500000).
p2_pi_acceptor(pyrimidine024,0.100000).
p2_polarizable(pyrimidine024,0.500000).
p2_sigma(pyrimidine024,0.260000).
p3_polar(pyrimidine024,0.633000).
p3_size(pyrimidine024,0.633000).
p3_flex(pyrimidine024,0.100000).
p3_h_donor(pyrimidine024,0.100000).
p3_h_acceptor(pyrimidine024,0.500000).
p3_pi_donor(pyrimidine024,0.500000).
p3_pi_acceptor(pyrimidine024,0.367000).
p3_sigma(pyrimidine024,0.367000).
activity(pyrimidine024,0.838000).
p1_polar(pyrimidine025,0.500000).
p1_size(pyrimidine025,0.260000).
p1_flex(pyrimidine025,0.100000).
p1_h_donor(pyrimidine025,0.100000).
p1_h_acceptor(pyrimidine025,0.100000).
p1_pi_donor(pyrimidine025,0.500000).
p1_pi_acceptor(pyrimidine025,0.100000).
p1_polarizable(pyrimidine025,0.633000).
p1_sigma(pyrimidine025,0.420000).
p2_polar(pyrimidine025,0.420000).
p2_size(pyrimidine025,0.260000).
p2_flex(pyrimidine025,0.100000).
p2_h_donor(pyrimidine025,0.900000).
p2_h_acceptor(pyrimidine025,0.100000).
p2_pi_donor(pyrimidine025,0.900000).
p2_pi_acceptor(pyrimidine025,0.100000).
p2_polarizable(pyrimidine025,0.100000).
p2_sigma(pyrimidine025,0.260000).
p3_polar(pyrimidine025,0.900000).
p3_size(pyrimidine025,0.367000).
p3_flex(pyrimidine025,0.100000).
p3_h_donor(pyrimidine025,0.100000).
p3_h_acceptor(pyrimidine025,0.100000).
p3_pi_donor(pyrimidine025,0.500000).
p3_pi_acceptor(pyrimidine025,0.633000).
p3_sigma(pyrimidine025,0.633000).
activity(pyrimidine025,0.897000).
p1_polar(pyrimidine026,0.100000).
p1_size(pyrimidine026,0.260000).
p1_flex(pyrimidine026,0.100000).
p1_h_donor(pyrimidine026,0.100000).
p1_h_acceptor(pyrimidine026,0.100000).
p1_pi_donor(pyrimidine026,0.100000).
p1_pi_acceptor(pyrimidine026,0.100000).
p1_polarizable(pyrimidine026,0.367000).
p1_sigma(pyrimidine026,0.100000).
p2_polar(pyrimidine026,0.420000).
p2_size(pyrimidine026,0.420000).
p2_flex(pyrimidine026,0.100000).
p2_h_donor(pyrimidine026,0.100000).
p2_h_acceptor(pyrimidine026,0.500000).
p2_pi_donor(pyrimidine026,0.500000).
p2_pi_acceptor(pyrimidine026,0.100000).
p2_polarizable(pyrimidine026,0.500000).
p2_sigma(pyrimidine026,0.260000).
p3_polar(pyrimidine026,0.367000).
p3_size(pyrimidine026,0.367000).
p3_flex(pyrimidine026,0.100000).
p3_h_donor(pyrimidine026,0.100000).
p3_h_acceptor(pyrimidine026,0.100000).
p3_pi_donor(pyrimidine026,0.100000).
p3_pi_acceptor(pyrimidine026,0.367000).
p3_sigma(pyrimidine026,0.100000).
activity(pyrimidine026,0.745000).
p1_polar(pyrimidine027,0.300000).
p1_size(pyrimidine027,0.900000).
p1_flex(pyrimidine027,0.800000).
p1_h_donor(pyrimidine027,0.100000).
p1_h_acceptor(pyrimidine027,0.500000).
p1_pi_donor(pyrimidine027,0.500000).
p1_pi_acceptor(pyrimidine027,0.100000).
p1_polarizable(pyrimidine027,0.367000).
p1_sigma(pyrimidine027,0.260000).
p2_polar(pyrimidine027,0.260000).
p2_size(pyrimidine027,0.100000).
p2_flex(pyrimidine027,0.100000).
p2_h_donor(pyrimidine027,0.100000).
p2_h_acceptor(pyrimidine027,0.100000).
p2_pi_donor(pyrimidine027,0.100000).
p2_pi_acceptor(pyrimidine027,0.100000).
p2_polarizable(pyrimidine027,0.100000).
p2_sigma(pyrimidine027,0.100000).
p3_polar(pyrimidine027,0.367000).
p3_size(pyrimidine027,0.100000).
p3_flex(pyrimidine027,0.100000).
p3_h_donor(pyrimidine027,0.100000).
p3_h_acceptor(pyrimidine027,0.100000).
p3_pi_donor(pyrimidine027,0.100000).
p3_pi_acceptor(pyrimidine027,0.100000).
p3_sigma(pyrimidine027,0.100000).
activity(pyrimidine027,0.560000).
p1_polar(pyrimidine028,0.100000).
p1_size(pyrimidine028,0.100000).
p1_flex(pyrimidine028,0.100000).
p1_h_donor(pyrimidine028,0.100000).
p1_h_acceptor(pyrimidine028,0.100000).
p1_pi_donor(pyrimidine028,0.100000).
p1_pi_acceptor(pyrimidine028,0.100000).
p1_polarizable(pyrimidine028,0.100000).
p1_sigma(pyrimidine028,0.100000).
p2_polar(pyrimidine028,0.740000).
p2_size(pyrimidine028,0.420000).
p2_flex(pyrimidine028,0.100000).
p2_h_donor(pyrimidine028,0.100000).
p2_h_acceptor(pyrimidine028,0.100000).
p2_pi_donor(pyrimidine028,0.100000).
p2_pi_acceptor(pyrimidine028,0.900000).
p2_polarizable(pyrimidine028,0.100000).
p2_sigma(pyrimidine028,0.580000).
p3_polar(pyrimidine028,0.367000).
p3_size(pyrimidine028,0.100000).
p3_flex(pyrimidine028,0.100000).
p3_h_donor(pyrimidine028,0.100000).
p3_h_acceptor(pyrimidine028,0.100000).
p3_pi_donor(pyrimidine028,0.100000).
p3_pi_acceptor(pyrimidine028,0.100000).
p3_sigma(pyrimidine028,0.100000).
activity(pyrimidine028,0.584000).
p1_polar(pyrimidine029,0.300000).
p1_size(pyrimidine029,0.420000).
p1_flex(pyrimidine029,0.100000).
p1_h_donor(pyrimidine029,0.100000).
p1_h_acceptor(pyrimidine029,0.500000).
p1_pi_donor(pyrimidine029,0.500000).
p1_pi_acceptor(pyrimidine029,0.100000).
p1_polarizable(pyrimidine029,0.367000).
p1_sigma(pyrimidine029,0.260000).
p2_polar(pyrimidine029,0.420000).
p2_size(pyrimidine029,0.420000).
p2_flex(pyrimidine029,0.100000).
p2_h_donor(pyrimidine029,0.100000).
p2_h_acceptor(pyrimidine029,0.500000).
p2_pi_donor(pyrimidine029,0.500000).
p2_pi_acceptor(pyrimidine029,0.100000).
p2_polarizable(pyrimidine029,0.500000).
p2_sigma(pyrimidine029,0.260000).
p3_polar(pyrimidine029,0.633000).
p3_size(pyrimidine029,0.633000).
p3_flex(pyrimidine029,0.100000).
p3_h_donor(pyrimidine029,0.100000).
p3_h_acceptor(pyrimidine029,0.500000).
p3_pi_donor(pyrimidine029,0.500000).
p3_pi_acceptor(pyrimidine029,0.367000).
p3_sigma(pyrimidine029,0.367000).
activity(pyrimidine029,0.900000).
p1_polar(pyrimidine030,0.300000).
p1_size(pyrimidine030,0.260000).
p1_flex(pyrimidine030,0.100000).
p1_h_donor(pyrimidine030,0.100000).
p1_h_acceptor(pyrimidine030,0.100000).
p1_pi_donor(pyrimidine030,0.500000).
p1_pi_acceptor(pyrimidine030,0.100000).
p1_polarizable(pyrimidine030,0.900000).
p1_sigma(pyrimidine030,0.260000).
p2_polar(pyrimidine030,0.580000).
p2_size(pyrimidine030,0.260000).
p2_flex(pyrimidine030,0.100000).
p2_h_donor(pyrimidine030,0.900000).
p2_h_acceptor(pyrimidine030,0.900000).
p2_pi_donor(pyrimidine030,0.900000).
p2_pi_acceptor(pyrimidine030,0.100000).
p2_polarizable(pyrimidine030,0.500000).
p2_sigma(pyrimidine030,0.420000).
p3_polar(pyrimidine030,0.633000).
p3_size(pyrimidine030,0.367000).
p3_flex(pyrimidine030,0.100000).
p3_h_donor(pyrimidine030,0.100000).
p3_h_acceptor(pyrimidine030,0.100000).
p3_pi_donor(pyrimidine030,0.500000).
p3_pi_acceptor(pyrimidine030,0.900000).
p3_sigma(pyrimidine030,0.367000).
activity(pyrimidine030,0.893000).
p1_polar(pyrimidine031,0.300000).
p1_size(pyrimidine031,0.580000).
p1_flex(pyrimidine031,0.500000).
p1_h_donor(pyrimidine031,0.100000).
p1_h_acceptor(pyrimidine031,0.900000).
p1_pi_donor(pyrimidine031,0.500000).
p1_pi_acceptor(pyrimidine031,0.100000).
p1_polarizable(pyrimidine031,0.367000).
p1_sigma(pyrimidine031,0.260000).
p2_polar(pyrimidine031,0.420000).
p2_size(pyrimidine031,0.580000).
p2_flex(pyrimidine031,0.500000).
p2_h_donor(pyrimidine031,0.100000).
p2_h_acceptor(pyrimidine031,0.900000).
p2_pi_donor(pyrimidine031,0.500000).
p2_pi_acceptor(pyrimidine031,0.100000).
p2_polarizable(pyrimidine031,0.500000).
p2_sigma(pyrimidine031,0.260000).
p3_polar(pyrimidine031,0.367000).
p3_size(pyrimidine031,0.100000).
p3_flex(pyrimidine031,0.100000).
p3_h_donor(pyrimidine031,0.100000).
p3_h_acceptor(pyrimidine031,0.100000).
p3_pi_donor(pyrimidine031,0.100000).
p3_pi_acceptor(pyrimidine031,0.100000).
p3_sigma(pyrimidine031,0.100000).
activity(pyrimidine031,0.674000).
p1_polar(pyrimidine032,0.500000).
p1_size(pyrimidine032,0.260000).
p1_flex(pyrimidine032,0.100000).
p1_h_donor(pyrimidine032,0.900000).
p1_h_acceptor(pyrimidine032,0.900000).
p1_pi_donor(pyrimidine032,0.900000).
p1_pi_acceptor(pyrimidine032,0.100000).
p1_polarizable(pyrimidine032,0.367000).
p1_sigma(pyrimidine032,0.420000).
p2_polar(pyrimidine032,0.580000).
p2_size(pyrimidine032,0.260000).
p2_flex(pyrimidine032,0.100000).
p2_h_donor(pyrimidine032,0.900000).
p2_h_acceptor(pyrimidine032,0.900000).
p2_pi_donor(pyrimidine032,0.900000).
p2_pi_acceptor(pyrimidine032,0.100000).
p2_polarizable(pyrimidine032,0.500000).
p2_sigma(pyrimidine032,0.420000).
p3_polar(pyrimidine032,0.367000).
p3_size(pyrimidine032,0.100000).
p3_flex(pyrimidine032,0.100000).
p3_h_donor(pyrimidine032,0.100000).
p3_h_acceptor(pyrimidine032,0.100000).
p3_pi_donor(pyrimidine032,0.100000).
p3_pi_acceptor(pyrimidine032,0.100000).
p3_sigma(pyrimidine032,0.100000).
activity(pyrimidine032,0.569000).
p1_polar(pyrimidine033,0.300000).
p1_size(pyrimidine033,0.580000).
p1_flex(pyrimidine033,0.500000).
p1_h_donor(pyrimidine033,0.100000).
p1_h_acceptor(pyrimidine033,0.900000).
p1_pi_donor(pyrimidine033,0.500000).
p1_pi_acceptor(pyrimidine033,0.100000).
p1_polarizable(pyrimidine033,0.367000).
p1_sigma(pyrimidine033,0.260000).
p2_polar(pyrimidine033,0.260000).
p2_size(pyrimidine033,0.100000).
p2_flex(pyrimidine033,0.100000).
p2_h_donor(pyrimidine033,0.100000).
p2_h_acceptor(pyrimidine033,0.100000).
p2_pi_donor(pyrimidine033,0.100000).
p2_pi_acceptor(pyrimidine033,0.100000).
p2_polarizable(pyrimidine033,0.100000).
p2_sigma(pyrimidine033,0.100000).
p3_polar(pyrimidine033,0.367000).
p3_size(pyrimidine033,0.100000).
p3_flex(pyrimidine033,0.100000).
p3_h_donor(pyrimidine033,0.100000).
p3_h_acceptor(pyrimidine033,0.100000).
p3_pi_donor(pyrimidine033,0.100000).
p3_pi_acceptor(pyrimidine033,0.100000).
p3_sigma(pyrimidine033,0.100000).
activity(pyrimidine033,0.579000).
p1_polar(pyrimidine034,0.300000).
p1_size(pyrimidine034,0.740000).
p1_flex(pyrimidine034,0.300000).
p1_h_donor(pyrimidine034,0.100000).
p1_h_acceptor(pyrimidine034,0.500000).
p1_pi_donor(pyrimidine034,0.500000).
p1_pi_acceptor(pyrimidine034,0.100000).
p1_polarizable(pyrimidine034,0.367000).
p1_sigma(pyrimidine034,0.260000).
p2_polar(pyrimidine034,0.260000).
p2_size(pyrimidine034,0.100000).
p2_flex(pyrimidine034,0.100000).
p2_h_donor(pyrimidine034,0.100000).
p2_h_acceptor(pyrimidine034,0.100000).
p2_pi_donor(pyrimidine034,0.100000).
p2_pi_acceptor(pyrimidine034,0.100000).
p2_polarizable(pyrimidine034,0.100000).
p2_sigma(pyrimidine034,0.100000).
p3_polar(pyrimidine034,0.367000).
p3_size(pyrimidine034,0.100000).
p3_flex(pyrimidine034,0.100000).
p3_h_donor(pyrimidine034,0.100000).
p3_h_acceptor(pyrimidine034,0.100000).
p3_pi_donor(pyrimidine034,0.100000).
p3_pi_acceptor(pyrimidine034,0.100000).
p3_sigma(pyrimidine034,0.100000).
activity(pyrimidine034,0.642000).
p1_polar(pyrimidine035,0.100000).
p1_size(pyrimidine035,0.260000).
p1_flex(pyrimidine035,0.100000).
p1_h_donor(pyrimidine035,0.100000).
p1_h_acceptor(pyrimidine035,0.100000).
p1_pi_donor(pyrimidine035,0.100000).
p1_pi_acceptor(pyrimidine035,0.100000).
p1_polarizable(pyrimidine035,0.367000).
p1_sigma(pyrimidine035,0.100000).
p2_polar(pyrimidine035,0.580000).
p2_size(pyrimidine035,0.260000).
p2_flex(pyrimidine035,0.100000).
p2_h_donor(pyrimidine035,0.900000).
p2_h_acceptor(pyrimidine035,0.900000).
p2_pi_donor(pyrimidine035,0.900000).
p2_pi_acceptor(pyrimidine035,0.100000).
p2_polarizable(pyrimidine035,0.500000).
p2_sigma(pyrimidine035,0.420000).
p3_polar(pyrimidine035,0.367000).
p3_size(pyrimidine035,0.367000).
p3_flex(pyrimidine035,0.100000).
p3_h_donor(pyrimidine035,0.100000).
p3_h_acceptor(pyrimidine035,0.100000).
p3_pi_donor(pyrimidine035,0.100000).
p3_pi_acceptor(pyrimidine035,0.367000).
p3_sigma(pyrimidine035,0.100000).
activity(pyrimidine035,0.720000).
p1_polar(pyrimidine036,0.100000).
p1_size(pyrimidine036,0.100000).
p1_flex(pyrimidine036,0.100000).
p1_h_donor(pyrimidine036,0.100000).
p1_h_acceptor(pyrimidine036,0.100000).
p1_pi_donor(pyrimidine036,0.100000).
p1_pi_acceptor(pyrimidine036,0.100000).
p1_polarizable(pyrimidine036,0.100000).
p1_sigma(pyrimidine036,0.100000).
p2_polar(pyrimidine036,0.580000).
p2_size(pyrimidine036,0.260000).
p2_flex(pyrimidine036,0.100000).
p2_h_donor(pyrimidine036,0.100000).
p2_h_acceptor(pyrimidine036,0.100000).
p2_pi_donor(pyrimidine036,0.500000).
p2_pi_acceptor(pyrimidine036,0.100000).
p2_polarizable(pyrimidine036,0.900000).
p2_sigma(pyrimidine036,0.420000).
p3_polar(pyrimidine036,0.367000).
p3_size(pyrimidine036,0.100000).
p3_flex(pyrimidine036,0.100000).
p3_h_donor(pyrimidine036,0.100000).
p3_h_acceptor(pyrimidine036,0.100000).
p3_pi_donor(pyrimidine036,0.100000).
p3_pi_acceptor(pyrimidine036,0.100000).
p3_sigma(pyrimidine036,0.100000).
activity(pyrimidine036,0.619000).
p1_polar(pyrimidine037,0.700000).
p1_size(pyrimidine037,0.580000).
p1_flex(pyrimidine037,0.200000).
p1_h_donor(pyrimidine037,0.100000).
p1_h_acceptor(pyrimidine037,0.100000).
p1_pi_donor(pyrimidine037,0.100000).
p1_pi_acceptor(pyrimidine037,0.500000).
p1_polarizable(pyrimidine037,0.633000).
p1_sigma(pyrimidine037,0.420000).
p2_polar(pyrimidine037,0.260000).
p2_size(pyrimidine037,0.100000).
p2_flex(pyrimidine037,0.100000).
p2_h_donor(pyrimidine037,0.100000).
p2_h_acceptor(pyrimidine037,0.100000).
p2_pi_donor(pyrimidine037,0.100000).
p2_pi_acceptor(pyrimidine037,0.100000).
p2_polarizable(pyrimidine037,0.100000).
p2_sigma(pyrimidine037,0.100000).
p3_polar(pyrimidine037,0.367000).
p3_size(pyrimidine037,0.100000).
p3_flex(pyrimidine037,0.100000).
p3_h_donor(pyrimidine037,0.100000).
p3_h_acceptor(pyrimidine037,0.100000).
p3_pi_donor(pyrimidine037,0.100000).
p3_pi_acceptor(pyrimidine037,0.100000).
p3_sigma(pyrimidine037,0.100000).
activity(pyrimidine037,0.632000).
p1_polar(pyrimidine038,0.100000).
p1_size(pyrimidine038,0.100000).
p1_flex(pyrimidine038,0.100000).
p1_h_donor(pyrimidine038,0.100000).
p1_h_acceptor(pyrimidine038,0.100000).
p1_pi_donor(pyrimidine038,0.100000).
p1_pi_acceptor(pyrimidine038,0.100000).
p1_polarizable(pyrimidine038,0.100000).
p1_sigma(pyrimidine038,0.100000).
p2_polar(pyrimidine038,0.420000).
p2_size(pyrimidine038,0.900000).
p2_flex(pyrimidine038,0.800000).
p2_h_donor(pyrimidine038,0.100000).
p2_h_acceptor(pyrimidine038,0.500000).
p2_pi_donor(pyrimidine038,0.500000).
p2_pi_acceptor(pyrimidine038,0.100000).
p2_polarizable(pyrimidine038,0.500000).
p2_sigma(pyrimidine038,0.260000).
p3_polar(pyrimidine038,0.367000).
p3_size(pyrimidine038,0.100000).
p3_flex(pyrimidine038,0.100000).
p3_h_donor(pyrimidine038,0.100000).
p3_h_acceptor(pyrimidine038,0.100000).
p3_pi_donor(pyrimidine038,0.100000).
p3_pi_acceptor(pyrimidine038,0.100000).
p3_sigma(pyrimidine038,0.100000).
activity(pyrimidine038,0.451000).
p1_polar(pyrimidine039,0.100000).
p1_size(pyrimidine039,0.100000).
p1_flex(pyrimidine039,0.100000).
p1_h_donor(pyrimidine039,0.100000).
p1_h_acceptor(pyrimidine039,0.100000).
p1_pi_donor(pyrimidine039,0.100000).
p1_pi_acceptor(pyrimidine039,0.100000).
p1_polarizable(pyrimidine039,0.100000).
p1_sigma(pyrimidine039,0.100000).
p2_polar(pyrimidine039,0.260000).
p2_size(pyrimidine039,0.260000).
p2_flex(pyrimidine039,0.100000).
p2_h_donor(pyrimidine039,0.100000).
p2_h_acceptor(pyrimidine039,0.100000).
p2_pi_donor(pyrimidine039,0.100000).
p2_pi_acceptor(pyrimidine039,0.100000).
p2_polarizable(pyrimidine039,0.500000).
p2_sigma(pyrimidine039,0.100000).
p3_polar(pyrimidine039,0.367000).
p3_size(pyrimidine039,0.100000).
p3_flex(pyrimidine039,0.100000).
p3_h_donor(pyrimidine039,0.100000).
p3_h_acceptor(pyrimidine039,0.100000).
p3_pi_donor(pyrimidine039,0.100000).
p3_pi_acceptor(pyrimidine039,0.100000).
p3_sigma(pyrimidine039,0.100000).
activity(pyrimidine039,0.572000).
p1_polar(pyrimidine040,0.500000).
p1_size(pyrimidine040,0.260000).
p1_flex(pyrimidine040,0.100000).
p1_h_donor(pyrimidine040,0.100000).
p1_h_acceptor(pyrimidine040,0.100000).
p1_pi_donor(pyrimidine040,0.100000).
p1_pi_acceptor(pyrimidine040,0.500000).
p1_polarizable(pyrimidine040,0.100000).
p1_sigma(pyrimidine040,0.580000).
p2_polar(pyrimidine040,0.420000).
p2_size(pyrimidine040,0.420000).
p2_flex(pyrimidine040,0.100000).
p2_h_donor(pyrimidine040,0.100000).
p2_h_acceptor(pyrimidine040,0.500000).
p2_pi_donor(pyrimidine040,0.500000).
p2_pi_acceptor(pyrimidine040,0.100000).
p2_polarizable(pyrimidine040,0.500000).
p2_sigma(pyrimidine040,0.260000).
p3_polar(pyrimidine040,0.367000).
p3_size(pyrimidine040,0.100000).
p3_flex(pyrimidine040,0.100000).
p3_h_donor(pyrimidine040,0.100000).
p3_h_acceptor(pyrimidine040,0.100000).
p3_pi_donor(pyrimidine040,0.100000).
p3_pi_acceptor(pyrimidine040,0.100000).
p3_sigma(pyrimidine040,0.100000).
activity(pyrimidine040,0.738000).
p1_polar(pyrimidine041,0.100000).
p1_size(pyrimidine041,0.100000).
p1_flex(pyrimidine041,0.100000).
p1_h_donor(pyrimidine041,0.100000).
p1_h_acceptor(pyrimidine041,0.100000).
p1_pi_donor(pyrimidine041,0.100000).
p1_pi_acceptor(pyrimidine041,0.100000).
p1_polarizable(pyrimidine041,0.100000).
p1_sigma(pyrimidine041,0.100000).
p2_polar(pyrimidine041,0.420000).
p2_size(pyrimidine041,0.580000).
p2_flex(pyrimidine041,0.500000).
p2_h_donor(pyrimidine041,0.100000).
p2_h_acceptor(pyrimidine041,0.900000).
p2_pi_donor(pyrimidine041,0.500000).
p2_pi_acceptor(pyrimidine041,0.100000).
p2_polarizable(pyrimidine041,0.500000).
p2_sigma(pyrimidine041,0.260000).
p3_polar(pyrimidine041,0.367000).
p3_size(pyrimidine041,0.100000).
p3_flex(pyrimidine041,0.100000).
p3_h_donor(pyrimidine041,0.100000).
p3_h_acceptor(pyrimidine041,0.100000).
p3_pi_donor(pyrimidine041,0.100000).
p3_pi_acceptor(pyrimidine041,0.100000).
p3_sigma(pyrimidine041,0.100000).
activity(pyrimidine041,0.561000).
p1_polar(pyrimidine042,0.300000).
p1_size(pyrimidine042,0.420000).
p1_flex(pyrimidine042,0.100000).
p1_h_donor(pyrimidine042,0.100000).
p1_h_acceptor(pyrimidine042,0.500000).
p1_pi_donor(pyrimidine042,0.500000).
p1_pi_acceptor(pyrimidine042,0.100000).
p1_polarizable(pyrimidine042,0.367000).
p1_sigma(pyrimidine042,0.260000).
p2_polar(pyrimidine042,0.420000).
p2_size(pyrimidine042,0.900000).
p2_flex(pyrimidine042,0.900000).
p2_h_donor(pyrimidine042,0.100000).
p2_h_acceptor(pyrimidine042,0.500000).
p2_pi_donor(pyrimidine042,0.500000).
p2_pi_acceptor(pyrimidine042,0.100000).
p2_polarizable(pyrimidine042,0.500000).
p2_sigma(pyrimidine042,0.260000).
p3_polar(pyrimidine042,0.633000).
p3_size(pyrimidine042,0.633000).
p3_flex(pyrimidine042,0.100000).
p3_h_donor(pyrimidine042,0.100000).
p3_h_acceptor(pyrimidine042,0.500000).
p3_pi_donor(pyrimidine042,0.500000).
p3_pi_acceptor(pyrimidine042,0.367000).
p3_sigma(pyrimidine042,0.367000).
activity(pyrimidine042,0.763000).
p1_polar(pyrimidine043,0.300000).
p1_size(pyrimidine043,0.900000).
p1_flex(pyrimidine043,0.700000).
p1_h_donor(pyrimidine043,0.100000).
p1_h_acceptor(pyrimidine043,0.500000).
p1_pi_donor(pyrimidine043,0.500000).
p1_pi_acceptor(pyrimidine043,0.100000).
p1_polarizable(pyrimidine043,0.367000).
p1_sigma(pyrimidine043,0.260000).
p2_polar(pyrimidine043,0.260000).
p2_size(pyrimidine043,0.100000).
p2_flex(pyrimidine043,0.100000).
p2_h_donor(pyrimidine043,0.100000).
p2_h_acceptor(pyrimidine043,0.100000).
p2_pi_donor(pyrimidine043,0.100000).
p2_pi_acceptor(pyrimidine043,0.100000).
p2_polarizable(pyrimidine043,0.100000).
p2_sigma(pyrimidine043,0.100000).
p3_polar(pyrimidine043,0.367000).
p3_size(pyrimidine043,0.100000).
p3_flex(pyrimidine043,0.100000).
p3_h_donor(pyrimidine043,0.100000).
p3_h_acceptor(pyrimidine043,0.100000).
p3_pi_donor(pyrimidine043,0.100000).
p3_pi_acceptor(pyrimidine043,0.100000).
p3_sigma(pyrimidine043,0.100000).
activity(pyrimidine043,0.624000).
p1_polar(pyrimidine044,0.100000).
p1_size(pyrimidine044,0.100000).
p1_flex(pyrimidine044,0.100000).
p1_h_donor(pyrimidine044,0.100000).
p1_h_acceptor(pyrimidine044,0.100000).
p1_pi_donor(pyrimidine044,0.100000).
p1_pi_acceptor(pyrimidine044,0.100000).
p1_polarizable(pyrimidine044,0.100000).
p1_sigma(pyrimidine044,0.100000).
p2_polar(pyrimidine044,0.900000).
p2_size(pyrimidine044,0.420000).
p2_flex(pyrimidine044,0.100000).
p2_h_donor(pyrimidine044,0.100000).
p2_h_acceptor(pyrimidine044,0.100000).
p2_pi_donor(pyrimidine044,0.100000).
p2_pi_acceptor(pyrimidine044,0.900000).
p2_polarizable(pyrimidine044,0.100000).
p2_sigma(pyrimidine044,0.580000).
p3_polar(pyrimidine044,0.367000).
p3_size(pyrimidine044,0.100000).
p3_flex(pyrimidine044,0.100000).
p3_h_donor(pyrimidine044,0.100000).
p3_h_acceptor(pyrimidine044,0.100000).
p3_pi_donor(pyrimidine044,0.100000).
p3_pi_acceptor(pyrimidine044,0.100000).
p3_sigma(pyrimidine044,0.100000).
activity(pyrimidine044,0.534000).
p1_polar(pyrimidine045,0.100000).
p1_size(pyrimidine045,0.100000).
p1_flex(pyrimidine045,0.100000).
p1_h_donor(pyrimidine045,0.100000).
p1_h_acceptor(pyrimidine045,0.100000).
p1_pi_donor(pyrimidine045,0.100000).
p1_pi_acceptor(pyrimidine045,0.100000).
p1_polarizable(pyrimidine045,0.100000).
p1_sigma(pyrimidine045,0.100000).
p2_polar(pyrimidine045,0.900000).
p2_size(pyrimidine045,0.260000).
p2_flex(pyrimidine045,0.100000).
p2_h_donor(pyrimidine045,0.100000).
p2_h_acceptor(pyrimidine045,0.500000).
p2_pi_donor(pyrimidine045,0.100000).
p2_pi_acceptor(pyrimidine045,0.100000).
p2_polarizable(pyrimidine045,0.100000).
p2_sigma(pyrimidine045,0.900000).
p3_polar(pyrimidine045,0.367000).
p3_size(pyrimidine045,0.100000).
p3_flex(pyrimidine045,0.100000).
p3_h_donor(pyrimidine045,0.100000).
p3_h_acceptor(pyrimidine045,0.100000).
p3_pi_donor(pyrimidine045,0.100000).
p3_pi_acceptor(pyrimidine045,0.100000).
p3_sigma(pyrimidine045,0.100000).
activity(pyrimidine045,0.554000).
p1_polar(pyrimidine046,0.100000).
p1_size(pyrimidine046,0.100000).
p1_flex(pyrimidine046,0.100000).
p1_h_donor(pyrimidine046,0.100000).
p1_h_acceptor(pyrimidine046,0.100000).
p1_pi_donor(pyrimidine046,0.100000).
p1_pi_acceptor(pyrimidine046,0.100000).
p1_polarizable(pyrimidine046,0.100000).
p1_sigma(pyrimidine046,0.100000).
p2_polar(pyrimidine046,0.420000).
p2_size(pyrimidine046,0.420000).
p2_flex(pyrimidine046,0.100000).
p2_h_donor(pyrimidine046,0.500000).
p2_h_acceptor(pyrimidine046,0.500000).
p2_pi_donor(pyrimidine046,0.500000).
p2_pi_acceptor(pyrimidine046,0.100000).
p2_polarizable(pyrimidine046,0.500000).
p2_sigma(pyrimidine046,0.260000).
p3_polar(pyrimidine046,0.367000).
p3_size(pyrimidine046,0.100000).
p3_flex(pyrimidine046,0.100000).
p3_h_donor(pyrimidine046,0.100000).
p3_h_acceptor(pyrimidine046,0.100000).
p3_pi_donor(pyrimidine046,0.100000).
p3_pi_acceptor(pyrimidine046,0.100000).
p3_sigma(pyrimidine046,0.100000).
activity(pyrimidine046,0.628000).
p1_polar(pyrimidine047,0.500000).
p1_size(pyrimidine047,0.260000).
p1_flex(pyrimidine047,0.100000).
p1_h_donor(pyrimidine047,0.100000).
p1_h_acceptor(pyrimidine047,0.100000).
p1_pi_donor(pyrimidine047,0.500000).
p1_pi_acceptor(pyrimidine047,0.100000).
p1_polarizable(pyrimidine047,0.633000).
p1_sigma(pyrimidine047,0.420000).
p2_polar(pyrimidine047,0.260000).
p2_size(pyrimidine047,0.100000).
p2_flex(pyrimidine047,0.100000).
p2_h_donor(pyrimidine047,0.100000).
p2_h_acceptor(pyrimidine047,0.100000).
p2_pi_donor(pyrimidine047,0.100000).
p2_pi_acceptor(pyrimidine047,0.100000).
p2_polarizable(pyrimidine047,0.100000).
p2_sigma(pyrimidine047,0.100000).
p3_polar(pyrimidine047,0.367000).
p3_size(pyrimidine047,0.100000).
p3_flex(pyrimidine047,0.100000).
p3_h_donor(pyrimidine047,0.100000).
p3_h_acceptor(pyrimidine047,0.100000).
p3_pi_donor(pyrimidine047,0.100000).
p3_pi_acceptor(pyrimidine047,0.100000).
p3_sigma(pyrimidine047,0.100000).
activity(pyrimidine047,0.638000).
p1_polar(pyrimidine048,0.300000).
p1_size(pyrimidine048,0.420000).
p1_flex(pyrimidine048,0.100000).
p1_h_donor(pyrimidine048,0.100000).
p1_h_acceptor(pyrimidine048,0.500000).
p1_pi_donor(pyrimidine048,0.500000).
p1_pi_acceptor(pyrimidine048,0.100000).
p1_polarizable(pyrimidine048,0.367000).
p1_sigma(pyrimidine048,0.260000).
p2_polar(pyrimidine048,0.420000).
p2_size(pyrimidine048,0.580000).
p2_flex(pyrimidine048,0.500000).
p2_h_donor(pyrimidine048,0.100000).
p2_h_acceptor(pyrimidine048,0.900000).
p2_pi_donor(pyrimidine048,0.500000).
p2_pi_acceptor(pyrimidine048,0.100000).
p2_polarizable(pyrimidine048,0.500000).
p2_sigma(pyrimidine048,0.260000).
p3_polar(pyrimidine048,0.633000).
p3_size(pyrimidine048,0.633000).
p3_flex(pyrimidine048,0.100000).
p3_h_donor(pyrimidine048,0.100000).
p3_h_acceptor(pyrimidine048,0.500000).
p3_pi_donor(pyrimidine048,0.500000).
p3_pi_acceptor(pyrimidine048,0.367000).
p3_sigma(pyrimidine048,0.367000).
activity(pyrimidine048,0.829000).
p1_polar(pyrimidine049,0.300000).
p1_size(pyrimidine049,0.580000).
p1_flex(pyrimidine049,0.200000).
p1_h_donor(pyrimidine049,0.500000).
p1_h_acceptor(pyrimidine049,0.900000).
p1_pi_donor(pyrimidine049,0.500000).
p1_pi_acceptor(pyrimidine049,0.100000).
p1_polarizable(pyrimidine049,0.100000).
p1_sigma(pyrimidine049,0.260000).
p2_polar(pyrimidine049,0.260000).
p2_size(pyrimidine049,0.100000).
p2_flex(pyrimidine049,0.100000).
p2_h_donor(pyrimidine049,0.100000).
p2_h_acceptor(pyrimidine049,0.100000).
p2_pi_donor(pyrimidine049,0.100000).
p2_pi_acceptor(pyrimidine049,0.100000).
p2_polarizable(pyrimidine049,0.100000).
p2_sigma(pyrimidine049,0.100000).
p3_polar(pyrimidine049,0.367000).
p3_size(pyrimidine049,0.100000).
p3_flex(pyrimidine049,0.100000).
p3_h_donor(pyrimidine049,0.100000).
p3_h_acceptor(pyrimidine049,0.100000).
p3_pi_donor(pyrimidine049,0.100000).
p3_pi_acceptor(pyrimidine049,0.100000).
p3_sigma(pyrimidine049,0.100000).
activity(pyrimidine049,0.584000).
p1_polar(pyrimidine050,0.100000).
p1_size(pyrimidine050,0.260000).
p1_flex(pyrimidine050,0.100000).
p1_h_donor(pyrimidine050,0.100000).
p1_h_acceptor(pyrimidine050,0.100000).
p1_pi_donor(pyrimidine050,0.100000).
p1_pi_acceptor(pyrimidine050,0.100000).
p1_polarizable(pyrimidine050,0.367000).
p1_sigma(pyrimidine050,0.100000).
p2_polar(pyrimidine050,0.260000).
p2_size(pyrimidine050,0.100000).
p2_flex(pyrimidine050,0.100000).
p2_h_donor(pyrimidine050,0.100000).
p2_h_acceptor(pyrimidine050,0.100000).
p2_pi_donor(pyrimidine050,0.100000).
p2_pi_acceptor(pyrimidine050,0.100000).
p2_polarizable(pyrimidine050,0.100000).
p2_sigma(pyrimidine050,0.100000).
p3_polar(pyrimidine050,0.367000).
p3_size(pyrimidine050,0.100000).
p3_flex(pyrimidine050,0.100000).
p3_h_donor(pyrimidine050,0.100000).
p3_h_acceptor(pyrimidine050,0.100000).
p3_pi_donor(pyrimidine050,0.100000).
p3_pi_acceptor(pyrimidine050,0.100000).
p3_sigma(pyrimidine050,0.100000).
activity(pyrimidine050,0.602000).
p1_polar(pyrimidine051,0.100000).
p1_size(pyrimidine051,0.100000).
p1_flex(pyrimidine051,0.100000).
p1_h_donor(pyrimidine051,0.100000).
p1_h_acceptor(pyrimidine051,0.100000).
p1_pi_donor(pyrimidine051,0.100000).
p1_pi_acceptor(pyrimidine051,0.100000).
p1_polarizable(pyrimidine051,0.100000).
p1_sigma(pyrimidine051,0.100000).
p2_polar(pyrimidine051,0.420000).
p2_size(pyrimidine051,0.580000).
p2_flex(pyrimidine051,0.500000).
p2_h_donor(pyrimidine051,0.100000).
p2_h_acceptor(pyrimidine051,0.500000).
p2_pi_donor(pyrimidine051,0.500000).
p2_pi_acceptor(pyrimidine051,0.100000).
p2_polarizable(pyrimidine051,0.500000).
p2_sigma(pyrimidine051,0.260000).
p3_polar(pyrimidine051,0.367000).
p3_size(pyrimidine051,0.100000).
p3_flex(pyrimidine051,0.100000).
p3_h_donor(pyrimidine051,0.100000).
p3_h_acceptor(pyrimidine051,0.100000).
p3_pi_donor(pyrimidine051,0.100000).
p3_pi_acceptor(pyrimidine051,0.100000).
p3_sigma(pyrimidine051,0.100000).
activity(pyrimidine051,0.628000).
p1_polar(pyrimidine052,0.500000).
p1_size(pyrimidine052,0.260000).
p1_flex(pyrimidine052,0.100000).
p1_h_donor(pyrimidine052,0.100000).
p1_h_acceptor(pyrimidine052,0.100000).
p1_pi_donor(pyrimidine052,0.500000).
p1_pi_acceptor(pyrimidine052,0.100000).
p1_polarizable(pyrimidine052,0.367000).
p1_sigma(pyrimidine052,0.580000).
p2_polar(pyrimidine052,0.260000).
p2_size(pyrimidine052,0.100000).
p2_flex(pyrimidine052,0.100000).
p2_h_donor(pyrimidine052,0.100000).
p2_h_acceptor(pyrimidine052,0.100000).
p2_pi_donor(pyrimidine052,0.100000).
p2_pi_acceptor(pyrimidine052,0.100000).
p2_polarizable(pyrimidine052,0.100000).
p2_sigma(pyrimidine052,0.100000).
p3_polar(pyrimidine052,0.367000).
p3_size(pyrimidine052,0.100000).
p3_flex(pyrimidine052,0.100000).
p3_h_donor(pyrimidine052,0.100000).
p3_h_acceptor(pyrimidine052,0.100000).
p3_pi_donor(pyrimidine052,0.100000).
p3_pi_acceptor(pyrimidine052,0.100000).
p3_sigma(pyrimidine052,0.100000).
activity(pyrimidine052,0.595000).
p1_polar(pyrimidine053,0.500000).
p1_size(pyrimidine053,0.260000).
p1_flex(pyrimidine053,0.100000).
p1_h_donor(pyrimidine053,0.100000).
p1_h_acceptor(pyrimidine053,0.100000).
p1_pi_donor(pyrimidine053,0.100000).
p1_pi_acceptor(pyrimidine053,0.500000).
p1_polarizable(pyrimidine053,0.100000).
p1_sigma(pyrimidine053,0.580000).
p2_polar(pyrimidine053,0.260000).
p2_size(pyrimidine053,0.100000).
p2_flex(pyrimidine053,0.100000).
p2_h_donor(pyrimidine053,0.100000).
p2_h_acceptor(pyrimidine053,0.100000).
p2_pi_donor(pyrimidine053,0.100000).
p2_pi_acceptor(pyrimidine053,0.100000).
p2_polarizable(pyrimidine053,0.100000).
p2_sigma(pyrimidine053,0.100000).
p3_polar(pyrimidine053,0.367000).
p3_size(pyrimidine053,0.100000).
p3_flex(pyrimidine053,0.100000).
p3_h_donor(pyrimidine053,0.100000).
p3_h_acceptor(pyrimidine053,0.100000).
p3_pi_donor(pyrimidine053,0.100000).
p3_pi_acceptor(pyrimidine053,0.100000).
p3_sigma(pyrimidine053,0.100000).
activity(pyrimidine053,0.646000).
p1_polar(pyrimidine054,0.300000).
p1_size(pyrimidine054,0.420000).
p1_flex(pyrimidine054,0.300000).
p1_h_donor(pyrimidine054,0.900000).
p1_h_acceptor(pyrimidine054,0.900000).
p1_pi_donor(pyrimidine054,0.100000).
p1_pi_acceptor(pyrimidine054,0.100000).
p1_polarizable(pyrimidine054,0.367000).
p1_sigma(pyrimidine054,0.100000).
p2_polar(pyrimidine054,0.260000).
p2_size(pyrimidine054,0.100000).
p2_flex(pyrimidine054,0.100000).
p2_h_donor(pyrimidine054,0.100000).
p2_h_acceptor(pyrimidine054,0.100000).
p2_pi_donor(pyrimidine054,0.100000).
p2_pi_acceptor(pyrimidine054,0.100000).
p2_polarizable(pyrimidine054,0.100000).
p2_sigma(pyrimidine054,0.100000).
p3_polar(pyrimidine054,0.367000).
p3_size(pyrimidine054,0.100000).
p3_flex(pyrimidine054,0.100000).
p3_h_donor(pyrimidine054,0.100000).
p3_h_acceptor(pyrimidine054,0.100000).
p3_pi_donor(pyrimidine054,0.100000).
p3_pi_acceptor(pyrimidine054,0.100000).
p3_sigma(pyrimidine054,0.100000).
activity(pyrimidine054,0.545000).
p1_polar(pyrimidine055,0.300000).
p1_size(pyrimidine055,0.260000).
p1_flex(pyrimidine055,0.100000).
p1_h_donor(pyrimidine055,0.100000).
p1_h_acceptor(pyrimidine055,0.100000).
p1_pi_donor(pyrimidine055,0.500000).
p1_pi_acceptor(pyrimidine055,0.100000).
p1_polarizable(pyrimidine055,0.900000).
p1_sigma(pyrimidine055,0.260000).
p2_polar(pyrimidine055,0.260000).
p2_size(pyrimidine055,0.100000).
p2_flex(pyrimidine055,0.100000).
p2_h_donor(pyrimidine055,0.100000).
p2_h_acceptor(pyrimidine055,0.100000).
p2_pi_donor(pyrimidine055,0.100000).
p2_pi_acceptor(pyrimidine055,0.100000).
p2_polarizable(pyrimidine055,0.100000).
p2_sigma(pyrimidine055,0.100000).
p3_polar(pyrimidine055,0.367000).
p3_size(pyrimidine055,0.100000).
p3_flex(pyrimidine055,0.100000).
p3_h_donor(pyrimidine055,0.100000).
p3_h_acceptor(pyrimidine055,0.100000).
p3_pi_donor(pyrimidine055,0.100000).
p3_pi_acceptor(pyrimidine055,0.100000).
p3_sigma(pyrimidine055,0.100000).
activity(pyrimidine055,0.675000).
p1_polar(pyrimidine056,0.100000).
p1_size(pyrimidine056,0.100000).
p1_flex(pyrimidine056,0.100000).
p1_h_donor(pyrimidine056,0.100000).
p1_h_acceptor(pyrimidine056,0.100000).
p1_pi_donor(pyrimidine056,0.100000).
p1_pi_acceptor(pyrimidine056,0.100000).
p1_polarizable(pyrimidine056,0.100000).
p1_sigma(pyrimidine056,0.100000).
p2_polar(pyrimidine056,0.580000).
p2_size(pyrimidine056,0.260000).
p2_flex(pyrimidine056,0.100000).
p2_h_donor(pyrimidine056,0.900000).
p2_h_acceptor(pyrimidine056,0.900000).
p2_pi_donor(pyrimidine056,0.900000).
p2_pi_acceptor(pyrimidine056,0.100000).
p2_polarizable(pyrimidine056,0.500000).
p2_sigma(pyrimidine056,0.420000).
p3_polar(pyrimidine056,0.367000).
p3_size(pyrimidine056,0.100000).
p3_flex(pyrimidine056,0.100000).
p3_h_donor(pyrimidine056,0.100000).
p3_h_acceptor(pyrimidine056,0.100000).
p3_pi_donor(pyrimidine056,0.100000).
p3_pi_acceptor(pyrimidine056,0.100000).
p3_sigma(pyrimidine056,0.100000).
activity(pyrimidine056,0.568000).
p1_polar(pyrimidine057,0.100000).
p1_size(pyrimidine057,0.100000).
p1_flex(pyrimidine057,0.100000).
p1_h_donor(pyrimidine057,0.100000).
p1_h_acceptor(pyrimidine057,0.100000).
p1_pi_donor(pyrimidine057,0.100000).
p1_pi_acceptor(pyrimidine057,0.100000).
p1_polarizable(pyrimidine057,0.100000).
p1_sigma(pyrimidine057,0.100000).
p2_polar(pyrimidine057,0.740000).
p2_size(pyrimidine057,0.580000).
p2_flex(pyrimidine057,0.200000).
p2_h_donor(pyrimidine057,0.100000).
p2_h_acceptor(pyrimidine057,0.100000).
p2_pi_donor(pyrimidine057,0.100000).
p2_pi_acceptor(pyrimidine057,0.500000).
p2_polarizable(pyrimidine057,0.900000).
p2_sigma(pyrimidine057,0.420000).
p3_polar(pyrimidine057,0.367000).
p3_size(pyrimidine057,0.100000).
p3_flex(pyrimidine057,0.100000).
p3_h_donor(pyrimidine057,0.100000).
p3_h_acceptor(pyrimidine057,0.100000).
p3_pi_donor(pyrimidine057,0.100000).
p3_pi_acceptor(pyrimidine057,0.100000).
p3_sigma(pyrimidine057,0.100000).
activity(pyrimidine057,0.589000).
p1_polar(pyrimidine058,0.500000).
p1_size(pyrimidine058,0.260000).
p1_flex(pyrimidine058,0.100000).
p1_h_donor(pyrimidine058,0.900000).
p1_h_acceptor(pyrimidine058,0.900000).
p1_pi_donor(pyrimidine058,0.900000).
p1_pi_acceptor(pyrimidine058,0.100000).
p1_polarizable(pyrimidine058,0.367000).
p1_sigma(pyrimidine058,0.420000).
p2_polar(pyrimidine058,0.420000).
p2_size(pyrimidine058,0.420000).
p2_flex(pyrimidine058,0.100000).
p2_h_donor(pyrimidine058,0.100000).
p2_h_acceptor(pyrimidine058,0.500000).
p2_pi_donor(pyrimidine058,0.500000).
p2_pi_acceptor(pyrimidine058,0.100000).
p2_polarizable(pyrimidine058,0.500000).
p2_sigma(pyrimidine058,0.260000).
p3_polar(pyrimidine058,0.367000).
p3_size(pyrimidine058,0.100000).
p3_flex(pyrimidine058,0.100000).
p3_h_donor(pyrimidine058,0.100000).
p3_h_acceptor(pyrimidine058,0.100000).
p3_pi_donor(pyrimidine058,0.100000).
p3_pi_acceptor(pyrimidine058,0.100000).
p3_sigma(pyrimidine058,0.100000).
activity(pyrimidine058,0.621000).
p1_polar(pyrimidine059,0.100000).
p1_size(pyrimidine059,0.100000).
p1_flex(pyrimidine059,0.100000).
p1_h_donor(pyrimidine059,0.100000).
p1_h_acceptor(pyrimidine059,0.100000).
p1_pi_donor(pyrimidine059,0.100000).
p1_pi_acceptor(pyrimidine059,0.100000).
p1_polarizable(pyrimidine059,0.100000).
p1_sigma(pyrimidine059,0.100000).
p2_polar(pyrimidine059,0.420000).
p2_size(pyrimidine059,0.740000).
p2_flex(pyrimidine059,0.300000).
p2_h_donor(pyrimidine059,0.100000).
p2_h_acceptor(pyrimidine059,0.500000).
p2_pi_donor(pyrimidine059,0.500000).
p2_pi_acceptor(pyrimidine059,0.100000).
p2_polarizable(pyrimidine059,0.500000).
p2_sigma(pyrimidine059,0.260000).
p3_polar(pyrimidine059,0.367000).
p3_size(pyrimidine059,0.100000).
p3_flex(pyrimidine059,0.100000).
p3_h_donor(pyrimidine059,0.100000).
p3_h_acceptor(pyrimidine059,0.100000).
p3_pi_donor(pyrimidine059,0.100000).
p3_pi_acceptor(pyrimidine059,0.100000).
p3_sigma(pyrimidine059,0.100000).
activity(pyrimidine059,0.628000).
p1_polar(pyrimidine060,0.100000).
p1_size(pyrimidine060,0.100000).
p1_flex(pyrimidine060,0.100000).
p1_h_donor(pyrimidine060,0.100000).
p1_h_acceptor(pyrimidine060,0.100000).
p1_pi_donor(pyrimidine060,0.100000).
p1_pi_acceptor(pyrimidine060,0.100000).
p1_polarizable(pyrimidine060,0.100000).
p1_sigma(pyrimidine060,0.100000).
p2_polar(pyrimidine060,0.100000).
p2_size(pyrimidine060,0.100000).
p2_flex(pyrimidine060,0.100000).
p2_h_donor(pyrimidine060,0.100000).
p2_h_acceptor(pyrimidine060,0.100000).
p2_pi_donor(pyrimidine060,0.100000).
p2_pi_acceptor(pyrimidine060,0.100000).
p2_polarizable(pyrimidine060,0.100000).
p2_sigma(pyrimidine060,0.100000).
p3_polar(pyrimidine060,0.367000).
p3_size(pyrimidine060,0.100000).
p3_flex(pyrimidine060,0.100000).
p3_h_donor(pyrimidine060,0.100000).
p3_h_acceptor(pyrimidine060,0.100000).
p3_pi_donor(pyrimidine060,0.100000).
p3_pi_acceptor(pyrimidine060,0.100000).
p3_sigma(pyrimidine060,0.100000).
activity(pyrimidine060,0.634000).
p1_polar(pyrimidine061,0.100000).
p1_size(pyrimidine061,0.260000).
p1_flex(pyrimidine061,0.100000).
p1_h_donor(pyrimidine061,0.100000).
p1_h_acceptor(pyrimidine061,0.100000).
p1_pi_donor(pyrimidine061,0.100000).
p1_pi_acceptor(pyrimidine061,0.100000).
p1_polarizable(pyrimidine061,0.367000).
p1_sigma(pyrimidine061,0.100000).
p2_polar(pyrimidine061,0.260000).
p2_size(pyrimidine061,0.100000).
p2_flex(pyrimidine061,0.100000).
p2_h_donor(pyrimidine061,0.100000).
p2_h_acceptor(pyrimidine061,0.100000).
p2_pi_donor(pyrimidine061,0.100000).
p2_pi_acceptor(pyrimidine061,0.100000).
p2_polarizable(pyrimidine061,0.100000).
p2_sigma(pyrimidine061,0.100000).
p3_polar(pyrimidine061,0.367000).
p3_size(pyrimidine061,0.367000).
p3_flex(pyrimidine061,0.100000).
p3_h_donor(pyrimidine061,0.100000).
p3_h_acceptor(pyrimidine061,0.100000).
p3_pi_donor(pyrimidine061,0.100000).
p3_pi_acceptor(pyrimidine061,0.367000).
p3_sigma(pyrimidine061,0.100000).
activity(pyrimidine061,0.649000).
p1_polar(pyrimidine062,0.300000).
p1_size(pyrimidine062,0.580000).
p1_flex(pyrimidine062,0.400000).
p1_h_donor(pyrimidine062,0.100000).
p1_h_acceptor(pyrimidine062,0.900000).
p1_pi_donor(pyrimidine062,0.500000).
p1_pi_acceptor(pyrimidine062,0.100000).
p1_polarizable(pyrimidine062,0.367000).
p1_sigma(pyrimidine062,0.260000).
p2_polar(pyrimidine062,0.260000).
p2_size(pyrimidine062,0.100000).
p2_flex(pyrimidine062,0.100000).
p2_h_donor(pyrimidine062,0.100000).
p2_h_acceptor(pyrimidine062,0.100000).
p2_pi_donor(pyrimidine062,0.100000).
p2_pi_acceptor(pyrimidine062,0.100000).
p2_polarizable(pyrimidine062,0.100000).
p2_sigma(pyrimidine062,0.100000).
p3_polar(pyrimidine062,0.633000).
p3_size(pyrimidine062,0.900000).
p3_flex(pyrimidine062,0.900000).
p3_h_donor(pyrimidine062,0.100000).
p3_h_acceptor(pyrimidine062,0.900000).
p3_pi_donor(pyrimidine062,0.500000).
p3_pi_acceptor(pyrimidine062,0.367000).
p3_sigma(pyrimidine062,0.367000).
activity(pyrimidine062,0.661000).
p1_polar(pyrimidine063,0.300000).
p1_size(pyrimidine063,0.900000).
p1_flex(pyrimidine063,0.900000).
p1_h_donor(pyrimidine063,0.100000).
p1_h_acceptor(pyrimidine063,0.500000).
p1_pi_donor(pyrimidine063,0.500000).
p1_pi_acceptor(pyrimidine063,0.100000).
p1_polarizable(pyrimidine063,0.367000).
p1_sigma(pyrimidine063,0.260000).
p2_polar(pyrimidine063,0.420000).
p2_size(pyrimidine063,0.420000).
p2_flex(pyrimidine063,0.100000).
p2_h_donor(pyrimidine063,0.100000).
p2_h_acceptor(pyrimidine063,0.500000).
p2_pi_donor(pyrimidine063,0.500000).
p2_pi_acceptor(pyrimidine063,0.100000).
p2_polarizable(pyrimidine063,0.500000).
p2_sigma(pyrimidine063,0.260000).
p3_polar(pyrimidine063,0.367000).
p3_size(pyrimidine063,0.100000).
p3_flex(pyrimidine063,0.100000).
p3_h_donor(pyrimidine063,0.100000).
p3_h_acceptor(pyrimidine063,0.100000).
p3_pi_donor(pyrimidine063,0.100000).
p3_pi_acceptor(pyrimidine063,0.100000).
p3_sigma(pyrimidine063,0.100000).
activity(pyrimidine063,0.665000).
p1_polar(pyrimidine064,0.300000).
p1_size(pyrimidine064,0.420000).
p1_flex(pyrimidine064,0.100000).
p1_h_donor(pyrimidine064,0.100000).
p1_h_acceptor(pyrimidine064,0.500000).
p1_pi_donor(pyrimidine064,0.500000).
p1_pi_acceptor(pyrimidine064,0.100000).
p1_polarizable(pyrimidine064,0.367000).
p1_sigma(pyrimidine064,0.260000).
p2_polar(pyrimidine064,0.420000).
p2_size(pyrimidine064,0.900000).
p2_flex(pyrimidine064,0.900000).
p2_h_donor(pyrimidine064,0.100000).
p2_h_acceptor(pyrimidine064,0.500000).
p2_pi_donor(pyrimidine064,0.500000).
p2_pi_acceptor(pyrimidine064,0.100000).
p2_polarizable(pyrimidine064,0.500000).
p2_sigma(pyrimidine064,0.260000).
p3_polar(pyrimidine064,0.633000).
p3_size(pyrimidine064,0.633000).
p3_flex(pyrimidine064,0.100000).
p3_h_donor(pyrimidine064,0.100000).
p3_h_acceptor(pyrimidine064,0.500000).
p3_pi_donor(pyrimidine064,0.500000).
p3_pi_acceptor(pyrimidine064,0.367000).
p3_sigma(pyrimidine064,0.367000).
activity(pyrimidine064,0.671000).
p1_polar(pyrimidine065,0.300000).
p1_size(pyrimidine065,0.740000).
p1_flex(pyrimidine065,0.400000).
p1_h_donor(pyrimidine065,0.100000).
p1_h_acceptor(pyrimidine065,0.500000).
p1_pi_donor(pyrimidine065,0.500000).
p1_pi_acceptor(pyrimidine065,0.100000).
p1_polarizable(pyrimidine065,0.367000).
p1_sigma(pyrimidine065,0.260000).
p2_polar(pyrimidine065,0.260000).
p2_size(pyrimidine065,0.100000).
p2_flex(pyrimidine065,0.100000).
p2_h_donor(pyrimidine065,0.100000).
p2_h_acceptor(pyrimidine065,0.100000).
p2_pi_donor(pyrimidine065,0.100000).
p2_pi_acceptor(pyrimidine065,0.100000).
p2_polarizable(pyrimidine065,0.100000).
p2_sigma(pyrimidine065,0.100000).
p3_polar(pyrimidine065,0.100000).
p3_size(pyrimidine065,0.100000).
p3_flex(pyrimidine065,0.100000).
p3_h_donor(pyrimidine065,0.100000).
p3_h_acceptor(pyrimidine065,0.100000).
p3_pi_donor(pyrimidine065,0.100000).
p3_pi_acceptor(pyrimidine065,0.100000).
p3_sigma(pyrimidine065,0.100000).
activity(pyrimidine065,0.700000).
p1_polar(pyrimidine066,0.300000).
p1_size(pyrimidine066,0.420000).
p1_flex(pyrimidine066,0.100000).
p1_h_donor(pyrimidine066,0.100000).
p1_h_acceptor(pyrimidine066,0.500000).
p1_pi_donor(pyrimidine066,0.500000).
p1_pi_acceptor(pyrimidine066,0.100000).
p1_polarizable(pyrimidine066,0.367000).
p1_sigma(pyrimidine066,0.260000).
p2_polar(pyrimidine066,0.420000).
p2_size(pyrimidine066,0.740000).
p2_flex(pyrimidine066,0.300000).
p2_h_donor(pyrimidine066,0.100000).
p2_h_acceptor(pyrimidine066,0.500000).
p2_pi_donor(pyrimidine066,0.500000).
p2_pi_acceptor(pyrimidine066,0.100000).
p2_polarizable(pyrimidine066,0.500000).
p2_sigma(pyrimidine066,0.260000).
p3_polar(pyrimidine066,0.367000).
p3_size(pyrimidine066,0.100000).
p3_flex(pyrimidine066,0.100000).
p3_h_donor(pyrimidine066,0.100000).
p3_h_acceptor(pyrimidine066,0.100000).
p3_pi_donor(pyrimidine066,0.100000).
p3_pi_acceptor(pyrimidine066,0.100000).
p3_sigma(pyrimidine066,0.100000).
activity(pyrimidine066,0.716000).
p1_polar(pyrimidine067,0.300000).
p1_size(pyrimidine067,0.420000).
p1_flex(pyrimidine067,0.100000).
p1_h_donor(pyrimidine067,0.100000).
p1_h_acceptor(pyrimidine067,0.500000).
p1_pi_donor(pyrimidine067,0.500000).
p1_pi_acceptor(pyrimidine067,0.100000).
p1_polarizable(pyrimidine067,0.367000).
p1_sigma(pyrimidine067,0.260000).
p2_polar(pyrimidine067,0.580000).
p2_size(pyrimidine067,0.260000).
p2_flex(pyrimidine067,0.100000).
p2_h_donor(pyrimidine067,0.900000).
p2_h_acceptor(pyrimidine067,0.900000).
p2_pi_donor(pyrimidine067,0.900000).
p2_pi_acceptor(pyrimidine067,0.100000).
p2_polarizable(pyrimidine067,0.500000).
p2_sigma(pyrimidine067,0.420000).
p3_polar(pyrimidine067,0.367000).
p3_size(pyrimidine067,0.100000).
p3_flex(pyrimidine067,0.100000).
p3_h_donor(pyrimidine067,0.100000).
p3_h_acceptor(pyrimidine067,0.100000).
p3_pi_donor(pyrimidine067,0.100000).
p3_pi_acceptor(pyrimidine067,0.100000).
p3_sigma(pyrimidine067,0.100000).
activity(pyrimidine067,0.717000).
p1_polar(pyrimidine068,0.300000).
p1_size(pyrimidine068,0.740000).
p1_flex(pyrimidine068,0.300000).
p1_h_donor(pyrimidine068,0.100000).
p1_h_acceptor(pyrimidine068,0.500000).
p1_pi_donor(pyrimidine068,0.500000).
p1_pi_acceptor(pyrimidine068,0.100000).
p1_polarizable(pyrimidine068,0.367000).
p1_sigma(pyrimidine068,0.260000).
p2_polar(pyrimidine068,0.420000).
p2_size(pyrimidine068,0.420000).
p2_flex(pyrimidine068,0.100000).
p2_h_donor(pyrimidine068,0.100000).
p2_h_acceptor(pyrimidine068,0.500000).
p2_pi_donor(pyrimidine068,0.500000).
p2_pi_acceptor(pyrimidine068,0.100000).
p2_polarizable(pyrimidine068,0.500000).
p2_sigma(pyrimidine068,0.260000).
p3_polar(pyrimidine068,0.367000).
p3_size(pyrimidine068,0.100000).
p3_flex(pyrimidine068,0.100000).
p3_h_donor(pyrimidine068,0.100000).
p3_h_acceptor(pyrimidine068,0.100000).
p3_pi_donor(pyrimidine068,0.100000).
p3_pi_acceptor(pyrimidine068,0.100000).
p3_sigma(pyrimidine068,0.100000).
activity(pyrimidine068,0.734000).
p1_polar(pyrimidine069,0.300000).
p1_size(pyrimidine069,0.420000).
p1_flex(pyrimidine069,0.100000).
p1_h_donor(pyrimidine069,0.100000).
p1_h_acceptor(pyrimidine069,0.500000).
p1_pi_donor(pyrimidine069,0.500000).
p1_pi_acceptor(pyrimidine069,0.100000).
p1_polarizable(pyrimidine069,0.367000).
p1_sigma(pyrimidine069,0.260000).
p2_polar(pyrimidine069,0.260000).
p2_size(pyrimidine069,0.420000).
p2_flex(pyrimidine069,0.100000).
p2_h_donor(pyrimidine069,0.100000).
p2_h_acceptor(pyrimidine069,0.500000).
p2_pi_donor(pyrimidine069,0.900000).
p2_pi_acceptor(pyrimidine069,0.100000).
p2_polarizable(pyrimidine069,0.500000).
p2_sigma(pyrimidine069,0.260000).
p3_polar(pyrimidine069,0.633000).
p3_size(pyrimidine069,0.633000).
p3_flex(pyrimidine069,0.100000).
p3_h_donor(pyrimidine069,0.100000).
p3_h_acceptor(pyrimidine069,0.500000).
p3_pi_donor(pyrimidine069,0.500000).
p3_pi_acceptor(pyrimidine069,0.367000).
p3_sigma(pyrimidine069,0.367000).
activity(pyrimidine069,0.741000).
p1_polar(pyrimidine070,0.300000).
p1_size(pyrimidine070,0.420000).
p1_flex(pyrimidine070,0.100000).
p1_h_donor(pyrimidine070,0.100000).
p1_h_acceptor(pyrimidine070,0.500000).
p1_pi_donor(pyrimidine070,0.500000).
p1_pi_acceptor(pyrimidine070,0.100000).
p1_polarizable(pyrimidine070,0.367000).
p1_sigma(pyrimidine070,0.260000).
p2_polar(pyrimidine070,0.420000).
p2_size(pyrimidine070,0.580000).
p2_flex(pyrimidine070,0.500000).
p2_h_donor(pyrimidine070,0.100000).
p2_h_acceptor(pyrimidine070,0.900000).
p2_pi_donor(pyrimidine070,0.500000).
p2_pi_acceptor(pyrimidine070,0.100000).
p2_polarizable(pyrimidine070,0.500000).
p2_sigma(pyrimidine070,0.260000).
p3_polar(pyrimidine070,0.367000).
p3_size(pyrimidine070,0.100000).
p3_flex(pyrimidine070,0.100000).
p3_h_donor(pyrimidine070,0.100000).
p3_h_acceptor(pyrimidine070,0.100000).
p3_pi_donor(pyrimidine070,0.100000).
p3_pi_acceptor(pyrimidine070,0.100000).
p3_sigma(pyrimidine070,0.100000).
activity(pyrimidine070,0.749000).
p1_polar(pyrimidine071,0.700000).
p1_size(pyrimidine071,0.580000).
p1_flex(pyrimidine071,0.200000).
p1_h_donor(pyrimidine071,0.100000).
p1_h_acceptor(pyrimidine071,0.100000).
p1_pi_donor(pyrimidine071,0.100000).
p1_pi_acceptor(pyrimidine071,0.500000).
p1_polarizable(pyrimidine071,0.633000).
p1_sigma(pyrimidine071,0.420000).
p2_polar(pyrimidine071,0.420000).
p2_size(pyrimidine071,0.420000).
p2_flex(pyrimidine071,0.100000).
p2_h_donor(pyrimidine071,0.100000).
p2_h_acceptor(pyrimidine071,0.500000).
p2_pi_donor(pyrimidine071,0.500000).
p2_pi_acceptor(pyrimidine071,0.100000).
p2_polarizable(pyrimidine071,0.500000).
p2_sigma(pyrimidine071,0.260000).
p3_polar(pyrimidine071,0.367000).
p3_size(pyrimidine071,0.100000).
p3_flex(pyrimidine071,0.100000).
p3_h_donor(pyrimidine071,0.100000).
p3_h_acceptor(pyrimidine071,0.100000).
p3_pi_donor(pyrimidine071,0.100000).
p3_pi_acceptor(pyrimidine071,0.100000).
p3_sigma(pyrimidine071,0.100000).
activity(pyrimidine071,0.753000).
p1_polar(pyrimidine072,0.100000).
p1_size(pyrimidine072,0.420000).
p1_flex(pyrimidine072,0.300000).
p1_h_donor(pyrimidine072,0.100000).
p1_h_acceptor(pyrimidine072,0.100000).
p1_pi_donor(pyrimidine072,0.100000).
p1_pi_acceptor(pyrimidine072,0.100000).
p1_polarizable(pyrimidine072,0.367000).
p1_sigma(pyrimidine072,0.100000).
p2_polar(pyrimidine072,0.260000).
p2_size(pyrimidine072,0.420000).
p2_flex(pyrimidine072,0.300000).
p2_h_donor(pyrimidine072,0.100000).
p2_h_acceptor(pyrimidine072,0.100000).
p2_pi_donor(pyrimidine072,0.100000).
p2_pi_acceptor(pyrimidine072,0.100000).
p2_polarizable(pyrimidine072,0.500000).
p2_sigma(pyrimidine072,0.100000).
p3_polar(pyrimidine072,0.367000).
p3_size(pyrimidine072,0.633000).
p3_flex(pyrimidine072,0.633000).
p3_h_donor(pyrimidine072,0.100000).
p3_h_acceptor(pyrimidine072,0.100000).
p3_pi_donor(pyrimidine072,0.100000).
p3_pi_acceptor(pyrimidine072,0.367000).
p3_sigma(pyrimidine072,0.100000).
activity(pyrimidine072,0.756000).
p1_polar(pyrimidine073,0.300000).
p1_size(pyrimidine073,0.420000).
p1_flex(pyrimidine073,0.100000).
p1_h_donor(pyrimidine073,0.100000).
p1_h_acceptor(pyrimidine073,0.500000).
p1_pi_donor(pyrimidine073,0.500000).
p1_pi_acceptor(pyrimidine073,0.100000).
p1_polarizable(pyrimidine073,0.367000).
p1_sigma(pyrimidine073,0.260000).
p2_polar(pyrimidine073,0.740000).
p2_size(pyrimidine073,0.580000).
p2_flex(pyrimidine073,0.200000).
p2_h_donor(pyrimidine073,0.100000).
p2_h_acceptor(pyrimidine073,0.100000).
p2_pi_donor(pyrimidine073,0.100000).
p2_pi_acceptor(pyrimidine073,0.500000).
p2_polarizable(pyrimidine073,0.900000).
p2_sigma(pyrimidine073,0.420000).
p3_polar(pyrimidine073,0.367000).
p3_size(pyrimidine073,0.100000).
p3_flex(pyrimidine073,0.100000).
p3_h_donor(pyrimidine073,0.100000).
p3_h_acceptor(pyrimidine073,0.100000).
p3_pi_donor(pyrimidine073,0.100000).
p3_pi_acceptor(pyrimidine073,0.100000).
p3_sigma(pyrimidine073,0.100000).
activity(pyrimidine073,0.772000).
p1_polar(pyrimidine074,0.300000).
p1_size(pyrimidine074,0.420000).
p1_flex(pyrimidine074,0.100000).
p1_h_donor(pyrimidine074,0.100000).
p1_h_acceptor(pyrimidine074,0.500000).
p1_pi_donor(pyrimidine074,0.500000).
p1_pi_acceptor(pyrimidine074,0.100000).
p1_polarizable(pyrimidine074,0.367000).
p1_sigma(pyrimidine074,0.260000).
p2_polar(pyrimidine074,0.580000).
p2_size(pyrimidine074,0.260000).
p2_flex(pyrimidine074,0.100000).
p2_h_donor(pyrimidine074,0.100000).
p2_h_acceptor(pyrimidine074,0.100000).
p2_pi_donor(pyrimidine074,0.500000).
p2_pi_acceptor(pyrimidine074,0.100000).
p2_polarizable(pyrimidine074,0.900000).
p2_sigma(pyrimidine074,0.420000).
p3_polar(pyrimidine074,0.633000).
p3_size(pyrimidine074,0.633000).
p3_flex(pyrimidine074,0.100000).
p3_h_donor(pyrimidine074,0.100000).
p3_h_acceptor(pyrimidine074,0.500000).
p3_pi_donor(pyrimidine074,0.500000).
p3_pi_acceptor(pyrimidine074,0.367000).
p3_sigma(pyrimidine074,0.367000).
activity(pyrimidine074,0.805000).
